@@ -42,27 +42,16 @@
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       conj_t  conjchi, \
-       ctype*  chi, \
-       ctype*  psi  \
+             conj_t conjchi, \
+       const ctype* chi, \
+             ctype* psi  \
      );
 
-INSERT_GENTPROT_BASIC0( addsc )
-INSERT_GENTPROT_BASIC0( divsc )
-INSERT_GENTPROT_BASIC0( mulsc )
-INSERT_GENTPROT_BASIC0( subsc )
-
-
-#undef  GENTPROT
-#define GENTPROT( ctype, ch, opname ) \
-\
-BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
-     ( \
-       conj_t  conjchi, \
-       ctype*  chi  \
-     );
-
-INSERT_GENTPROT_BASIC0( invertsc )
+INSERT_GENTPROT_BASIC( addsc )
+INSERT_GENTPROT_BASIC( divsc )
+INSERT_GENTPROT_BASIC( mulsc )
+INSERT_GENTPROT_BASIC( subsc )
+INSERT_GENTPROT_BASIC( invertsc )
 
 
 #undef  GENTPROTR
@@ -70,12 +59,12 @@ INSERT_GENTPROT_BASIC0( invertsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       ctype*   chi, \
-       ctype_r* absq  \
+       const ctype*   chi, \
+             ctype_r* absq  \
      );
 
-INSERT_GENTPROTR_BASIC0( absqsc )
-INSERT_GENTPROTR_BASIC0( normfsc )
+INSERT_GENTPROTR_BASIC( absqsc )
+INSERT_GENTPROTR_BASIC( normfsc )
 
 
 #undef  GENTPROT
@@ -83,11 +72,12 @@ INSERT_GENTPROTR_BASIC0( normfsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       ctype*  chi, \
-       ctype*  psi  \
+       const ctype* chi, \
+             ctype* psi  \
      );
 
-INSERT_GENTPROT_BASIC0( sqrtsc )
+INSERT_GENTPROT_BASIC( sqrtsc )
+INSERT_GENTPROT_BASIC( sqrtrsc )
 
 
 #undef  GENTPROT
@@ -95,12 +85,12 @@ INSERT_GENTPROT_BASIC0( sqrtsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       ctype*  chi, \
-       double* zeta_r, \
-       double* zeta_i  \
+       const ctype*  chi, \
+             double* zeta_r, \
+             double* zeta_i  \
      );
 
-INSERT_GENTPROT_BASIC0( getsc )
+INSERT_GENTPROT_BASIC( getsc )
 
 
 #undef  GENTPROT
@@ -108,12 +98,12 @@ INSERT_GENTPROT_BASIC0( getsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       double  zeta_r, \
-       double  zeta_i, \
-       ctype*  chi  \
+       double zeta_r, \
+       double zeta_i, \
+       ctype* chi  \
      );
 
-INSERT_GENTPROT_BASIC0( setsc )
+INSERT_GENTPROT_BASIC( setsc )
 
 
 #undef  GENTPROTR
@@ -121,12 +111,12 @@ INSERT_GENTPROT_BASIC0( setsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       ctype*   chi, \
-       ctype_r* zeta_r, \
-       ctype_r* zeta_i  \
+       const ctype*   chi, \
+             ctype_r* zeta_r, \
+             ctype_r* zeta_i  \
      );
 
-INSERT_GENTPROTR_BASIC0( unzipsc )
+INSERT_GENTPROTR_BASIC( unzipsc )
 
 
 #undef  GENTPROTR
@@ -134,26 +124,26 @@ INSERT_GENTPROTR_BASIC0( unzipsc )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
      ( \
-       ctype_r* zeta_r, \
-       ctype_r* zeta_i, \
-       ctype*   chi  \
+       const ctype_r* zeta_r, \
+       const ctype_r* zeta_i, \
+             ctype*   chi  \
      );
 
-INSERT_GENTPROTR_BASIC0( zipsc )
+INSERT_GENTPROTR_BASIC( zipsc )
 
 // -----------------------------------------------------------------------------
 
 BLIS_EXPORT_BLIS void bli_igetsc
      (
-       dim_t*  chi,
-       double* zeta_r,
-       double* zeta_i
+       const dim_t*  chi,
+             double* zeta_r,
+             double* zeta_i
      );
 
 BLIS_EXPORT_BLIS void bli_isetsc
      (
-       double  zeta_r,
-       double  zeta_i,
-       dim_t*  chi
+       double zeta_r,
+       double zeta_i,
+       dim_t* chi
      );
 
