@@ -42,19 +42,19 @@
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t  diagoffx, \
-       diag_t  diagx, \
-       trans_t transx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  x, inc_t rs_x, inc_t cs_x, \
-       ctype*  y, inc_t rs_y, inc_t cs_y  \
+             doff_t  diagoffx, \
+             diag_t  diagx, \
+             trans_t transx, \
+             dim_t   m, \
+             dim_t   n, \
+       const ctype*  x, inc_t rs_x, inc_t cs_x, \
+             ctype*  y, inc_t rs_y, inc_t cs_y  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( addd )
-INSERT_GENTPROT_BASIC0( copyd )
-INSERT_GENTPROT_BASIC0( subd )
+INSERT_GENTPROT_BASIC( addd )
+INSERT_GENTPROT_BASIC( copyd )
+INSERT_GENTPROT_BASIC( subd )
 
 
 #undef  GENTPROT
@@ -62,19 +62,19 @@ INSERT_GENTPROT_BASIC0( subd )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t  diagoffx, \
-       diag_t  diagx, \
-       trans_t transx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  alpha, \
-       ctype*  x, inc_t rs_x, inc_t cs_x, \
-       ctype*  y, inc_t rs_y, inc_t cs_y  \
+             doff_t  diagoffx, \
+             diag_t  diagx, \
+             trans_t transx, \
+             dim_t   m, \
+             dim_t   n, \
+       const ctype*  alpha, \
+       const ctype*  x, inc_t rs_x, inc_t cs_x, \
+             ctype*  y, inc_t rs_y, inc_t cs_y  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( axpyd )
-INSERT_GENTPROT_BASIC0( scal2d )
+INSERT_GENTPROT_BASIC( axpyd )
+INSERT_GENTPROT_BASIC( scal2d )
 
 
 #undef  GENTPROT
@@ -82,14 +82,14 @@ INSERT_GENTPROT_BASIC0( scal2d )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t  diagoffx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  x, inc_t rs_x, inc_t cs_x  \
+       doff_t diagoffx, \
+       dim_t  m, \
+       dim_t  n, \
+       ctype* x, inc_t rs_x, inc_t cs_x  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( invertd )
+INSERT_GENTPROT_BASIC( invertd )
 
 
 #undef  GENTPROT
@@ -97,17 +97,18 @@ INSERT_GENTPROT_BASIC0( invertd )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conjalpha, \
-       doff_t  diagoffx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  alpha, \
-       ctype*  x, inc_t rs_x, inc_t cs_x  \
+             conj_t conjalpha, \
+             doff_t diagoffx, \
+             dim_t  m, \
+             dim_t  n, \
+       const ctype* alpha, \
+             ctype* x, inc_t rs_x, inc_t cs_x  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( scald )
-INSERT_GENTPROT_BASIC0( setd )
+INSERT_GENTPROT_BASIC( invscald )
+INSERT_GENTPROT_BASIC( scald )
+INSERT_GENTPROT_BASIC( setd )
 
 
 #undef  GENTPROTR
@@ -115,15 +116,15 @@ INSERT_GENTPROT_BASIC0( setd )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t   diagoffx, \
-       dim_t    m, \
-       dim_t    n, \
-       ctype_r* alpha, \
-       ctype*   x, inc_t rs_x, inc_t cs_x  \
+             doff_t   diagoffx, \
+             dim_t    m, \
+             dim_t    n, \
+       const ctype_r* alpha, \
+             ctype*   x, inc_t rs_x, inc_t cs_x  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROTR_BASIC0( setid )
+INSERT_GENTPROTR_BASIC( setid )
 
 
 #undef  GENTPROT
@@ -131,15 +132,15 @@ INSERT_GENTPROTR_BASIC0( setid )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t  diagoffx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  alpha, \
-       ctype*  x, inc_t rs_x, inc_t cs_x  \
+             doff_t diagoffx, \
+             dim_t  m, \
+             dim_t  n, \
+       const ctype* alpha, \
+             ctype* x, inc_t rs_x, inc_t cs_x  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( shiftd )
+INSERT_GENTPROT_BASIC( shiftd )
 
 
 #undef  GENTPROT
@@ -147,16 +148,16 @@ INSERT_GENTPROT_BASIC0( shiftd )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t  diagoffx, \
-       diag_t  diagx, \
-       trans_t transx, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  x, inc_t rs_x, inc_t cs_x, \
-       ctype*  beta, \
-       ctype*  y, inc_t rs_y, inc_t cs_y  \
+             doff_t  diagoffx, \
+             diag_t  diagx, \
+             trans_t transx, \
+             dim_t   m, \
+             dim_t   n, \
+       const ctype*  x, inc_t rs_x, inc_t cs_x, \
+       const ctype*  beta, \
+             ctype*  y, inc_t rs_y, inc_t cs_y  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( xpbyd )
+INSERT_GENTPROT_BASIC( xpbyd )
 
