@@ -42,18 +42,18 @@
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conjx, \
-       conj_t  conjy, \
-       dim_t   n, \
-       ctype*  alphax, \
-       ctype*  alphay, \
-       ctype*  x, inc_t incx, \
-       ctype*  y, inc_t incy, \
-       ctype*  z, inc_t incz  \
+             conj_t conjx, \
+             conj_t conjy, \
+             dim_t  n, \
+       const ctype* alphax, \
+       const ctype* alphay, \
+       const ctype* x, inc_t incx, \
+       const ctype* y, inc_t incy, \
+             ctype* z, inc_t incz  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( axpy2v )
+INSERT_GENTPROT_BASIC( axpy2v )
 
 
 #undef  GENTPROT
@@ -61,18 +61,18 @@ INSERT_GENTPROT_BASIC0( axpy2v )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conja, \
-       conj_t  conjx, \
-       dim_t   m, \
-       dim_t   b_n, \
-       ctype*  alpha, \
-       ctype*  a, inc_t inca, inc_t lda, \
-       ctype*  x, inc_t incx, \
-       ctype*  y, inc_t incy  \
+             conj_t conja, \
+             conj_t conjx, \
+             dim_t  m, \
+             dim_t  b_n, \
+       const ctype* alpha, \
+       const ctype* a, inc_t inca, inc_t lda, \
+       const ctype* x, inc_t incx, \
+             ctype* y, inc_t incy  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( axpyf )
+INSERT_GENTPROT_BASIC( axpyf )
 
 
 #undef  GENTPROT
@@ -80,19 +80,19 @@ INSERT_GENTPROT_BASIC0( axpyf )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conjxt, \
-       conj_t  conjx, \
-       conj_t  conjy, \
-       dim_t   n, \
-       ctype*  alpha, \
-       ctype*  x, inc_t incx, \
-       ctype*  y, inc_t incy, \
-       ctype*  rho, \
-       ctype*  z, inc_t incz  \
+             conj_t conjxt, \
+             conj_t conjx, \
+             conj_t conjy, \
+             dim_t  n, \
+       const ctype* alpha, \
+       const ctype* x, inc_t incx, \
+       const ctype* y, inc_t incy, \
+             ctype* rho, \
+             ctype* z, inc_t incz  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( dotaxpyv )
+INSERT_GENTPROT_BASIC( dotaxpyv )
 
 
 #undef  GENTPROT
@@ -100,23 +100,23 @@ INSERT_GENTPROT_BASIC0( dotaxpyv )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conjat, \
-       conj_t  conja, \
-       conj_t  conjw, \
-       conj_t  conjx, \
-       dim_t   m, \
-       dim_t   b_n, \
-       ctype*  alpha, \
-       ctype*  a, inc_t inca, inc_t lda, \
-       ctype*  w, inc_t incw, \
-       ctype*  x, inc_t incx, \
-       ctype*  beta, \
-       ctype*  y, inc_t incy, \
-       ctype*  z, inc_t incz  \
+             conj_t conjat, \
+             conj_t conja, \
+             conj_t conjw, \
+             conj_t conjx, \
+             dim_t  m, \
+             dim_t  b_n, \
+       const ctype* alpha, \
+       const ctype* a, inc_t inca, inc_t lda, \
+       const ctype* w, inc_t incw, \
+       const ctype* x, inc_t incx, \
+       const ctype* beta, \
+             ctype* y, inc_t incy, \
+             ctype* z, inc_t incz  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( dotxaxpyf )
+INSERT_GENTPROT_BASIC( dotxaxpyf )
 
 
 #undef  GENTPROT
@@ -124,17 +124,17 @@ INSERT_GENTPROT_BASIC0( dotxaxpyf )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       conj_t  conjat, \
-       conj_t  conjx, \
-       dim_t   m, \
-       dim_t   b_n, \
-       ctype*  alpha, \
-       ctype*  a, inc_t inca, inc_t lda, \
-       ctype*  x, inc_t incx, \
-       ctype*  beta, \
-       ctype*  y, inc_t incy  \
+             conj_t conjat, \
+             conj_t conjx, \
+             dim_t  m, \
+             dim_t  b_n, \
+       const ctype* alpha, \
+       const ctype* a, inc_t inca, inc_t lda, \
+       const ctype* x, inc_t incx, \
+       const ctype* beta, \
+             ctype* y, inc_t incy  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( dotxf )
+INSERT_GENTPROT_BASIC( dotxf )
 
