@@ -35,7 +35,7 @@
 #include "bli_l1m_check.h"
 
 // Define kernel function types.
-#include "bli_l1m_ft_ker.h"
+#include "bli_l1m_ker_ft.h"
 
 // Define object function types for variants.
 #include "bli_l1m_oft_var.h"
@@ -43,18 +43,22 @@
 // Prototype object APIs (expert and non-expert).
 #include "bli_oapi_ex.h"
 #include "bli_l1m_oapi.h"
+#include "bli_xapi_undef.h"
 
 #include "bli_oapi_ba.h"
 #include "bli_l1m_oapi.h"
+#include "bli_xapi_undef.h"
 
 // Prototype typed APIs (expert and non-expert).
 #include "bli_tapi_ex.h"
 #include "bli_l1m_tapi.h"
 #include "bli_l1m_ft.h"
+#include "bli_xapi_undef.h"
 
 #include "bli_tapi_ba.h"
 #include "bli_l1m_tapi.h"
 #include "bli_l1m_ft.h"
+#include "bli_xapi_undef.h"
 
 // Generate function pointer arrays for tapi functions (expert only).
 #include "bli_l1m_fpa.h"
