@@ -36,12 +36,11 @@
 
 void bli_packm_int
      (
-       obj_t*  a,
-       obj_t*  p,
-       cntx_t* cntx,
-       rntm_t* rntm,
-       cntl_t* cntl,
-       thrinfo_t* thread
+       const obj_t*     a,
+             obj_t*     p,
+       const cntx_t*    cntx,
+       const cntl_t*    cntl,
+             thrinfo_t* thread_par
      )
 {
 	bli_init_once();
@@ -51,20 +50,29 @@ void bli_packm_int
 
 	// Barrier so that we know threads are done with previous computation
 	// with the same packing buffer before starting to pack.
-	bli_thread_barrier( thread );
+	thrinfo_t* thread = bli_thrinfo_sub_node( thread_par );
+	bli_thrinfo_barrier( thread );
 
-	// Invoke the variant with kappa_use.
+	// Invoke the packm variant.
+	// NOTE: The packing kernel uses two communicators: one which represents a
+	// single workgroup of many threads, and one which represents a group of
+	// many single-member workgroups. The former communicator is used for
+	// barriers and thread communication (i.e. broadcasting the pack buffer
+	// pointer), while the latter communicator is used for partitioning work.
+	// This is because all of the thread range functions rely on the work_id
+	// and number of workgroups (n_way). Thus, we pass along the parent
+	// thrinfo_t node which has these two communicators as the sub-node and
+	// sub-prenode, respectively.
 	f
 	(
 	  a,
 	  p,
 	  cntx,
-	  rntm,
 	  cntl,
-	  thread
+	  thread_par
 	);
 
 	// Barrier so that packing is done before computation.
-	bli_thread_barrier( thread );
+	bli_thrinfo_barrier( thread );
 }
 
