@@ -42,11 +42,11 @@
 \
 BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  x, \
-       obj_t*  beta, \
-       obj_t*  y  \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* x, \
+       const obj_t* beta, \
+       const obj_t* y  \
        BLIS_OAPI_EX_PARAMS  \
      );
 
@@ -60,10 +60,10 @@ GENPROT( symv )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  x, \
-       obj_t*  y, \
-       obj_t*  a  \
+       const obj_t* alpha, \
+       const obj_t* x, \
+       const obj_t* y, \
+       const obj_t* a  \
        BLIS_OAPI_EX_PARAMS  \
      );
 
@@ -77,9 +77,9 @@ GENPROT( syr2 )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  x, \
-       obj_t*  a  \
+       const obj_t* alpha, \
+       const obj_t* x, \
+       const obj_t* a  \
        BLIS_OAPI_EX_PARAMS  \
      );
 
@@ -92,9 +92,9 @@ GENPROT( syr )
 \
 BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  x  \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* x  \
        BLIS_OAPI_EX_PARAMS  \
      );
 
