@@ -35,20 +35,19 @@
 
 
 //
-// Prototype object-based interfaces.
+// Prototype object-based interfaces (basic).
 //
 
 #undef  GENPROT
 #define GENPROT( opname ) \
 \
-BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
+BLIS_EXPORT_BLIS void PASTEMAC0(opname) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  b, \
-       obj_t*  beta, \
-       obj_t*  c  \
-       BLIS_OAPI_EX_PARAMS  \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* b, \
+       const obj_t* beta, \
+       const obj_t* c  \
      );
 
 GENPROT( gemm )
@@ -60,15 +59,14 @@ GENPROT( syr2k )
 #undef  GENPROT
 #define GENPROT( opname ) \
 \
-BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
+BLIS_EXPORT_BLIS void PASTEMAC0(opname) \
      ( \
-       side_t  side, \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  b, \
-       obj_t*  beta, \
-       obj_t*  c  \
-       BLIS_OAPI_EX_PARAMS  \
+             side_t side, \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* b, \
+       const obj_t* beta, \
+       const obj_t* c  \
      );
 
 GENPROT( hemm )
@@ -79,13 +77,12 @@ GENPROT( trmm3 )
 #undef  GENPROT
 #define GENPROT( opname ) \
 \
-BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
+BLIS_EXPORT_BLIS void PASTEMAC0(opname) \
      ( \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  beta, \
-       obj_t*  c  \
-       BLIS_OAPI_EX_PARAMS  \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* beta, \
+       const obj_t* c  \
      );
 
 GENPROT( herk )
@@ -95,13 +92,12 @@ GENPROT( syrk )
 #undef  GENPROT
 #define GENPROT( opname ) \
 \
-BLIS_EXPORT_BLIS void PASTEMAC(opname,EX_SUF) \
+BLIS_EXPORT_BLIS void PASTEMAC0(opname) \
      ( \
-       side_t  side, \
-       obj_t*  alpha, \
-       obj_t*  a, \
-       obj_t*  b  \
-       BLIS_OAPI_EX_PARAMS  \
+             side_t side, \
+       const obj_t* alpha, \
+       const obj_t* a, \
+       const obj_t* b  \
      );
 
 GENPROT( trmm )
