@@ -36,14 +36,14 @@
 
 err_t bli_gemmsup_int
      (
-       obj_t*  alpha,
-       obj_t*  a,
-       obj_t*  b,
-       obj_t*  beta,
-       obj_t*  c,
-       cntx_t* cntx,
-       rntm_t* rntm,
-       thrinfo_t* thread
+       const obj_t*  alpha,
+       const obj_t*  a,
+       const obj_t*  b,
+       const obj_t*  beta,
+       const obj_t*  c,
+       const cntx_t* cntx,
+       const rntm_t* rntm,
+             thrinfo_t* thread
      )
 {
 #if 0
@@ -78,13 +78,6 @@ err_t bli_gemmsup_int
 
 	const stor3_t stor_id = bli_obj_stor3_from_strides( c, a, b );
 
-	// Don't use the small/unpacked implementation if one of the matrices
-	// uses general stride.
-	if ( stor_id == BLIS_XXX )
-	{
-		return BLIS_FAILURE;
-	}
-
 	const bool    is_rrr_rrc_rcr_crr = ( stor_id == BLIS_RRR ||
 	                                     stor_id == BLIS_RRC ||
 	                                     stor_id == BLIS_RCR ||
@@ -92,7 +85,7 @@ err_t bli_gemmsup_int
 	const bool    is_rcc_crc_ccr_ccc = !is_rrr_rrc_rcr_crr;
 
 	const num_t   dt         = bli_obj_dt( c );
-	const bool    row_pref   = bli_cntx_l3_sup_ker_prefers_rows_dt( dt, stor_id, cntx );
+	const bool    row_pref   = bli_cntx_ukr_prefers_rows_dt( dt, bli_stor3_ukr( stor_id ), cntx );
 
 	const bool    is_primary = ( row_pref ? is_rrr_rrc_rcr_crr
 	                                      : is_rcc_crc_ccr_ccc );
@@ -144,15 +137,16 @@ err_t bli_gemmsup_int
 			// Update the ways of parallelism for the jc and ic loops, and then
 			// update the current thread's root thrinfo_t node according to the
 			// new ways of parallelism value for the jc loop.
-			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, rntm );
-			bli_l3_sup_thrinfo_update_root( rntm, thread );
+			rntm_t rntm_l = *rntm;
+			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, &rntm_l );
+			bli_l3_sup_thrinfo_update( &rntm_l, &thread );
 		}
 
 
 		if ( use_bp )
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var2m primary\n" );
 			#endif
 			// block-panel macrokernel; m -> mc, mr; n -> nc, nr: var2()
@@ -163,7 +157,7 @@ err_t bli_gemmsup_int
 		else // use_pb
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var1n primary\n" );
 			#endif
 			// panel-block macrokernel; m -> nc*,mr; n -> mc*,nr: var1()
@@ -209,15 +203,16 @@ err_t bli_gemmsup_int
 			// Update the ways of parallelism for the jc and ic loops, and then
 			// update the current thread's root thrinfo_t node according to the
 			// new ways of parallelism value for the jc loop.
-			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, rntm );
-			bli_l3_sup_thrinfo_update_root( rntm, thread );
+			rntm_t rntm_l = *rntm;
+			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, &rntm_l );
+			bli_l3_sup_thrinfo_update( &rntm_l, &thread );
 		}
 
 
 		if ( use_bp )
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var2m non-primary\n" );
 			#endif
 			// panel-block macrokernel; m -> nc, nr; n -> mc, mr: var2() + trans
@@ -228,7 +223,7 @@ err_t bli_gemmsup_int
 		else // use_pb
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var1n non-primary\n" );
 			#endif
 			// block-panel macrokernel; m -> mc*,nr; n -> nc*,mr: var1() + trans
@@ -247,25 +242,18 @@ err_t bli_gemmsup_int
 
 err_t bli_gemmtsup_int
      (
-       obj_t*  alpha,
-       obj_t*  a,
-       obj_t*  b,
-       obj_t*  beta,
-       obj_t*  c,
-       cntx_t* cntx,
-       rntm_t* rntm,
-       thrinfo_t* thread
+       const obj_t*  alpha,
+       const obj_t*  a,
+       const obj_t*  b,
+       const obj_t*  beta,
+       const obj_t*  c,
+       const cntx_t* cntx,
+       const rntm_t* rntm,
+             thrinfo_t* thread
      )
 {
 	const stor3_t stor_id = bli_obj_stor3_from_strides( c, a, b );
 
-	// Don't use the small/unpacked implementation if one of the matrices
-	// uses general stride.
-	if ( stor_id == BLIS_XXX )
-	{
-		return BLIS_FAILURE;
-	}
-
 	const bool    is_rrr_rrc_rcr_crr = ( stor_id == BLIS_RRR ||
 	                                     stor_id == BLIS_RRC ||
 	                                     stor_id == BLIS_RCR ||
@@ -273,7 +261,7 @@ err_t bli_gemmtsup_int
 	const bool    is_rcc_crc_ccr_ccc = !is_rrr_rrc_rcr_crr;
 
 	const num_t   dt         = bli_obj_dt( c );
-	const bool    row_pref   = bli_cntx_l3_sup_ker_prefers_rows_dt( dt, stor_id, cntx );
+	const bool    row_pref   = bli_cntx_ukr_prefers_rows_dt( dt, bli_stor3_ukr( stor_id ), cntx );
 
 	const bool    is_primary = ( row_pref ? is_rrr_rrc_rcr_crr
 	                                      : is_rcc_crc_ccr_ccc );
@@ -325,15 +313,16 @@ err_t bli_gemmtsup_int
 			// Update the ways of parallelism for the jc and ic loops, and then
 			// update the current thread's root thrinfo_t node according to the
 			// new ways of parallelism value for the jc loop.
-			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, rntm );
-			bli_l3_sup_thrinfo_update_root( rntm, thread );
+			rntm_t rntm_l = *rntm;
+			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, &rntm_l );
+			bli_l3_sup_thrinfo_update( &rntm_l, &thread );
 		}
 
 
 		if ( use_bp )
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var2m primary\n" );
 			#endif
 			// block-panel macrokernel; m -> mc, mr; n -> nc, nr: var2()
@@ -346,7 +335,7 @@ err_t bli_gemmtsup_int
 		else // use_pb
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var1n primary\n" );
 			#endif
 			// panel-block macrokernel; m -> nc*,mr; n -> mc*,nr: var1()
@@ -394,15 +383,16 @@ err_t bli_gemmtsup_int
 			// Update the ways of parallelism for the jc and ic loops, and then
 			// update the current thread's root thrinfo_t node according to the
 			// new ways of parallelism value for the jc loop.
-			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, rntm );
-			bli_l3_sup_thrinfo_update_root( rntm, thread );
+			rntm_t rntm_l = *rntm;
+			bli_rntm_set_ways_only( jc_new, 1, ic_new, 1, 1, &rntm_l );
+			bli_l3_sup_thrinfo_update( &rntm_l, &thread );
 		}
 
 
 		if ( use_bp )
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var2m non-primary\n" );
 			#endif
 			// panel-block macrokernel; m -> nc, nr; n -> mc, mr: var2() + trans
@@ -415,7 +405,7 @@ err_t bli_gemmtsup_int
 		else // use_pb
 		{
 			#ifdef TRACEVAR
-			if ( bli_thread_am_ochief( thread ) )
+			if ( bli_thrinfo_am_chief( thread ) )
 			printf( "bli_l3_sup_int(): var1n non-primary\n" );
 			#endif
 			// block-panel macrokernel; m -> mc*,nr; n -> nc*,mr: var1() + trans
