@@ -47,13 +47,13 @@
 \
 typedef err_t (*PASTECH(opname,_oft)) \
 ( \
-  obj_t*  alpha, \
-  obj_t*  a, \
-  obj_t*  b, \
-  obj_t*  beta, \
-  obj_t*  c, \
-  cntx_t* cntx, \
-  rntm_t* rntm  \
+  const obj_t*  alpha, \
+  const obj_t*  a, \
+  const obj_t*  b, \
+  const obj_t*  beta, \
+  const obj_t*  c, \
+  const cntx_t* cntx, \
+  const rntm_t* rntm  \
 );
 
 GENTDEF( gemmsup )
