@@ -34,62 +34,158 @@
 */
 
 #include "blis.h"
-#include "assert.h"
 
-void bli_l3_thrinfo_init_single
+thrinfo_t* bli_l3_thrinfo_create
      (
-       thrinfo_t* thread
+             dim_t       id,
+             thrcomm_t*  gl_comm,
+             array_t*    array,
+       const rntm_t*     rntm,
+       const cntl_t*     cntl
      )
 {
-	bli_thrinfo_init_single( thread );
+	pool_t* sba_pool = bli_sba_array_elem( id, array );
+
+	// Create the root thrinfo_t node.
+	thrinfo_t* root = bli_thrinfo_create_root
+	(
+	  gl_comm,
+	  id,
+	  sba_pool,
+	  bli_pba_query()
+	);
+
+	bli_l3_thrinfo_grow( root, rntm, cntl );
+
+	return root;
 }
 
-void bli_l3_thrinfo_free
+void bli_l3_thrinfo_grow
      (
-       rntm_t*    rntm,
-       thrinfo_t* thread
+             thrinfo_t*  thread_par,
+       const rntm_t*     rntm,
+       const cntl_t*     cntl
      )
 {
-	bli_thrinfo_free( rntm, thread );
+	const cntl_t* sub_prenode = bli_cntl_sub_prenode( cntl );
+	const cntl_t* sub_node    = bli_cntl_sub_node( cntl );
+	const bszid_t bszid       = bli_cntl_bszid( cntl );
+	const dim_t   n_way       = bli_rntm_ways_for( bszid, rntm );
+
+	thrinfo_t* thread_cur = bli_thrinfo_split( n_way, thread_par );
+	bli_thrinfo_set_sub_node( thread_cur, thread_par );
+
+	if ( bszid == BLIS_NO_PART )
+	{
+		// A hack: the packing code needs a thread communicator which represents
+		// a group of single-member thread teams working cooperatively However,
+		// the "normal" packm thrinfo_t node has a single team of multiple
+		// threads. Our solution (for now) is to create a sub-prenode on the
+		// thrinfo_t tree which splits this single team into multiple
+		// single-member thread teams.
+		const dim_t n_threads = bli_thrinfo_num_threads( thread_par );
+		thrinfo_t* thread_pre = bli_thrinfo_split( n_threads, thread_par );
+		bli_thrinfo_set_sub_prenode( thread_pre, thread_par );
+	}
+	else if ( sub_prenode != NULL )
+	{
+		// A pre-node is only used in the IC loop of trsm. In this case,
+		// we cannot actually thread in the m dimension due to data dependencies
+		// and so all parallelism must be moved down to the JR loop.
+		rntm_t rntm_l = *rntm;
+		const dim_t ic_nway = bli_rntm_ic_ways( &rntm_l );
+		const dim_t jr_nway = bli_rntm_jr_ways( &rntm_l );
+		bli_rntm_set_ic_ways_only(               1, &rntm_l );
+		bli_rntm_set_jr_ways_only( ic_nway*jr_nway, &rntm_l );
+
+		// Use thread_pre instead of thread_cur since we *don't* want to do any
+		// parallelism at this level. So the thread_pre node gets attached to
+		// thread_par and not thread_cur! This results in a split "one level
+		// higher" than in the corresponding cntl_t tree. This is intentional
+		// since two different thrinfo_t nodes will be used at the cntl_t node
+		// for trsm blocked variant 1 (one for trsm, one for gemm).
+		thrinfo_t* thread_pre = bli_thrinfo_split( 1, thread_par );
+		bli_thrinfo_set_sub_prenode( thread_pre, thread_par );
+		bli_l3_thrinfo_grow( thread_pre, &rntm_l, sub_prenode );
+	}
+
+	if ( sub_node != NULL )
+	{
+		bli_l3_thrinfo_grow( thread_cur, rntm, sub_node );
+	}
 }
 
 // -----------------------------------------------------------------------------
 
-void bli_l3_thrinfo_create_root
+thrinfo_t* bli_l3_sup_thrinfo_create
      (
-       dim_t       id,
-       thrcomm_t*  gl_comm,
-       rntm_t*     rntm,
-       cntl_t*     cntl,
-       thrinfo_t** thread
+             dim_t      id,
+             thrcomm_t* gl_comm,
+             pool_t*    sba_pool,
+       const rntm_t*    rntm
      )
 {
-	// Query the global communicator for the total number of threads to use.
-	dim_t   n_threads  = bli_thrcomm_num_threads( gl_comm );
-
-	// Use the thread id passed in as the global communicator id.
-	dim_t   gl_comm_id = id;
-
-	// Use the blocksize id of the current (root) control tree node to
-	// query the top-most ways of parallelism to obtain.
-	bszid_t bszid      = bli_cntl_bszid( cntl );
-	dim_t   xx_way     = bli_rntm_ways_for( bszid, rntm );
-
-	// Determine the work id for this thrinfo_t node.
-	dim_t   work_id    = gl_comm_id / ( n_threads / xx_way );
-
 	// Create the root thrinfo_t node.
-	*thread = bli_thrinfo_create
+	thrinfo_t* root = bli_thrinfo_create_root
 	(
-	  rntm,
 	  gl_comm,
-	  gl_comm_id,
-	  xx_way,
-	  work_id,
-	  TRUE,
-	  bszid,
-	  NULL
+	  id,
+	  sba_pool,
+	  bli_pba_query()
 	);
+
+	const dim_t n_way_jc = bli_rntm_ways_for( BLIS_NC, rntm );
+	const dim_t n_way_pc = bli_rntm_ways_for( BLIS_KC, rntm );
+	const dim_t n_way_ic = bli_rntm_ways_for( BLIS_MC, rntm );
+	const dim_t n_way_jr = bli_rntm_ways_for( BLIS_NR, rntm );
+	const dim_t n_way_ir = bli_rntm_ways_for( BLIS_MR, rntm );
+
+	thrinfo_t* thread_jc = bli_thrinfo_split( n_way_jc,      root );
+	thrinfo_t* thread_pc = bli_thrinfo_split( n_way_pc, thread_jc );
+	thrinfo_t* thread_pb = bli_thrinfo_split(        1, thread_pc );
+	thrinfo_t* thread_ic = bli_thrinfo_split( n_way_ic, thread_pb );
+	thrinfo_t* thread_pa = bli_thrinfo_split(        1, thread_ic );
+	thrinfo_t* thread_jr = bli_thrinfo_split( n_way_jr, thread_pa );
+	thrinfo_t* thread_ir = bli_thrinfo_split( n_way_ir, thread_jr );
+
+	const dim_t n_way_pb = bli_thrinfo_num_threads( thread_pb );
+	const dim_t n_way_pa = bli_thrinfo_num_threads( thread_pa );
+
+	// Create and set the prenodes for the packb and packa thrinfo_t nodes.
+	thrinfo_t* thread_pb_single = bli_thrinfo_split( n_way_pb, thread_pb );
+	thrinfo_t* thread_pa_single = bli_thrinfo_split( n_way_pa, thread_pa );
+	bli_thrinfo_set_sub_prenode( thread_pb_single, thread_pb );
+	bli_thrinfo_set_sub_prenode( thread_pa_single, thread_pa );
+
+	bli_thrinfo_set_sub_node( thread_jc,      root );
+	bli_thrinfo_set_sub_node( thread_pc, thread_jc );
+	bli_thrinfo_set_sub_node( thread_pb, thread_pc );
+	bli_thrinfo_set_sub_node( thread_ic, thread_pb );
+	bli_thrinfo_set_sub_node( thread_pa, thread_ic );
+	bli_thrinfo_set_sub_node( thread_jr, thread_pa );
+	bli_thrinfo_set_sub_node( thread_ir, thread_jr );
+
+	return root;
+}
+
+void bli_l3_sup_thrinfo_update
+     (
+       const rntm_t*     rntm,
+             thrinfo_t** root
+     )
+{
+	thrcomm_t* gl_comm  = bli_thrinfo_comm( *root );
+	dim_t      tid      = bli_thrinfo_thread_id( *root );
+	pool_t*    sba_pool = bli_thrinfo_sba_pool( *root );
+	dim_t      nt       = bli_thrinfo_num_threads( *root );
+
+	// Return early in single-threaded execution
+	// since the thread control tree may not have been
+	// allocated normally
+	if ( nt == 1 ) return;
+
+	bli_thrinfo_free( *root );
+	*root = bli_l3_sup_thrinfo_create( tid, gl_comm, sba_pool, rntm );
 }
 
 // -----------------------------------------------------------------------------
@@ -101,7 +197,7 @@ void bli_l3_thrinfo_print_gemm_paths
 {
 	// In order to query the number of threads, we query the only thread we
 	// know exists: thread 0.
-	dim_t n_threads = bli_thread_num_threads( threads[0] );
+	dim_t n_threads = bli_thrinfo_num_threads( threads[0] );
 
 	// For the purposes of printing the "header" information that is common
 	// to the various instances of a thrinfo_t (ie: across all threads), we
@@ -134,44 +230,44 @@ void bli_l3_thrinfo_print_gemm_paths
 
 	if ( !jc_info ) goto print_header;
 
-	jc_way  = bli_thread_n_way( jc_info );
-	jc_nt   = bli_thread_num_threads( jc_info );
+	jc_way  = bli_thrinfo_n_way( jc_info );
+	jc_nt   = bli_thrinfo_num_threads( jc_info );
 	pc_info = bli_thrinfo_sub_node( jc_info );
 
 	if ( !pc_info ) goto print_header;
 
-	pc_way  = bli_thread_n_way( pc_info );
-	pc_nt   = bli_thread_num_threads( pc_info );
+	pc_way  = bli_thrinfo_n_way( pc_info );
+	pc_nt   = bli_thrinfo_num_threads( pc_info );
 	pb_info = bli_thrinfo_sub_node( pc_info );
 
 	if ( !pb_info ) goto print_header;
 
-	pb_way  = bli_thread_n_way( pb_info );
-	pb_nt   = bli_thread_num_threads( pb_info );
+	pb_way  = bli_thrinfo_n_way( pb_info );
+	pb_nt   = bli_thrinfo_num_threads( pb_info );
 	ic_info = bli_thrinfo_sub_node( pb_info );
 
 	if ( !ic_info ) goto print_header;
 
-	ic_way  = bli_thread_n_way( ic_info );
-	ic_nt   = bli_thread_num_threads( ic_info );
+	ic_way  = bli_thrinfo_n_way( ic_info );
+	ic_nt   = bli_thrinfo_num_threads( ic_info );
 	pa_info = bli_thrinfo_sub_node( ic_info );
 
 	if ( !pa_info ) goto print_header;
 
-	pa_way  = bli_thread_n_way( pa_info );
-	pa_nt   = bli_thread_num_threads( pa_info );
+	pa_way  = bli_thrinfo_n_way( pa_info );
+	pa_nt   = bli_thrinfo_num_threads( pa_info );
 	jr_info = bli_thrinfo_sub_node( pa_info );
 
 	if ( !jr_info ) goto print_header;
 
-	jr_way  = bli_thread_n_way( jr_info );
-	jr_nt   = bli_thread_num_threads( jr_info );
+	jr_way  = bli_thrinfo_n_way( jr_info );
+	jr_nt   = bli_thrinfo_num_threads( jr_info );
 	ir_info = bli_thrinfo_sub_node( jr_info );
 
 	if ( !ir_info ) goto print_header;
 
-	ir_way  = bli_thread_n_way( ir_info );
-	ir_nt   = bli_thread_num_threads( ir_info );
+	ir_way  = bli_thrinfo_n_way( ir_info );
+	ir_nt   = bli_thrinfo_num_threads( ir_info );
 
 	print_header:
 
@@ -185,7 +281,7 @@ void bli_l3_thrinfo_print_gemm_paths
 	( unsigned long )jr_nt,
 	( unsigned long )ir_nt );
 	printf( "xx_way:   %4ld %4ld %4ld %4ld %4ld %4ld %4ld\n",
-    ( unsigned long )jc_way,
+	( unsigned long )jc_way,
 	( unsigned long )pc_way,
 	( unsigned long )pb_way,
 	( unsigned long )ic_way,
@@ -206,44 +302,44 @@ void bli_l3_thrinfo_print_gemm_paths
 
 		if ( !jc_info ) goto print_thrinfo;
 
-		jc_comm_id = bli_thread_ocomm_id( jc_info );
-		jc_work_id = bli_thread_work_id( jc_info );
+		jc_comm_id = bli_thrinfo_thread_id( jc_info );
+		jc_work_id = bli_thrinfo_work_id( jc_info );
 		pc_info    = bli_thrinfo_sub_node( jc_info );
 
 		if ( !pc_info ) goto print_thrinfo;
 
-		pc_comm_id = bli_thread_ocomm_id( pc_info );
-		pc_work_id = bli_thread_work_id( pc_info );
+		pc_comm_id = bli_thrinfo_thread_id( pc_info );
+		pc_work_id = bli_thrinfo_work_id( pc_info );
 		pb_info    = bli_thrinfo_sub_node( pc_info );
 
 		if ( !pb_info ) goto print_thrinfo;
 
-		pb_comm_id = bli_thread_ocomm_id( pb_info );
-		pb_work_id = bli_thread_work_id( pb_info );
+		pb_comm_id = bli_thrinfo_thread_id( pb_info );
+		pb_work_id = bli_thrinfo_work_id( pb_info );
 		ic_info    = bli_thrinfo_sub_node( pb_info );
 
 		if ( !ic_info ) goto print_thrinfo;
 
-		ic_comm_id = bli_thread_ocomm_id( ic_info );
-		ic_work_id = bli_thread_work_id( ic_info );
+		ic_comm_id = bli_thrinfo_thread_id( ic_info );
+		ic_work_id = bli_thrinfo_work_id( ic_info );
 		pa_info    = bli_thrinfo_sub_node( ic_info );
 
 		if ( !pa_info ) goto print_thrinfo;
 
-		pa_comm_id = bli_thread_ocomm_id( pa_info );
-		pa_work_id = bli_thread_work_id( pa_info );
+		pa_comm_id = bli_thrinfo_thread_id( pa_info );
+		pa_work_id = bli_thrinfo_work_id( pa_info );
 		jr_info    = bli_thrinfo_sub_node( pa_info );
 
 		if ( !jr_info ) goto print_thrinfo;
 
-		jr_comm_id = bli_thread_ocomm_id( jr_info );
-		jr_work_id = bli_thread_work_id( jr_info );
+		jr_comm_id = bli_thrinfo_thread_id( jr_info );
+		jr_work_id = bli_thrinfo_work_id( jr_info );
 		ir_info    = bli_thrinfo_sub_node( jr_info );
 
 		if ( !ir_info ) goto print_thrinfo;
 
-		ir_comm_id = bli_thread_ocomm_id( ir_info );
-		ir_work_id = bli_thread_work_id( ir_info );
+		ir_comm_id = bli_thrinfo_thread_id( ir_info );
+		ir_work_id = bli_thrinfo_work_id( ir_info );
 
 		print_thrinfo:
 
@@ -279,7 +375,7 @@ void bli_l3_thrinfo_print_trsm_paths
 {
 	// In order to query the number of threads, we query the only thread we
 	// know exists: thread 0.
-	dim_t n_threads = bli_thread_num_threads( threads[0] );
+	dim_t n_threads = bli_thrinfo_num_threads( threads[0] );
 
 	// For the purposes of printing the "header" information that is common
 	// to the various instances of a thrinfo_t (ie: across all threads), we
@@ -314,26 +410,26 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	if ( !jc_info ) goto print_header;
 
-	jc_way   = bli_thread_n_way( jc_info );
-	jc_nt    = bli_thread_num_threads( jc_info );
+	jc_way   = bli_thrinfo_n_way( jc_info );
+	jc_nt    = bli_thrinfo_num_threads( jc_info );
 	pc_info  = bli_thrinfo_sub_node( jc_info );
 
 	if ( !pc_info ) goto print_header;
 
-	pc_way   = bli_thread_n_way( pc_info );
-	pc_nt    = bli_thread_num_threads( pc_info );
+	pc_way   = bli_thrinfo_n_way( pc_info );
+	pc_nt    = bli_thrinfo_num_threads( pc_info );
 	pb_info  = bli_thrinfo_sub_node( pc_info );
 
 	if ( !pb_info ) goto print_header;
 
-	pb_way   = bli_thread_n_way( pb_info );
-	pb_nt    = bli_thread_num_threads( pb_info );
+	pb_way   = bli_thrinfo_n_way( pb_info );
+	pb_nt    = bli_thrinfo_num_threads( pb_info );
 	ic_info  = bli_thrinfo_sub_node( pb_info );
 
 	if ( !ic_info ) goto print_header;
 
-	ic_way   = bli_thread_n_way( ic_info );
-	ic_nt    = bli_thread_num_threads( ic_info );
+	ic_way   = bli_thrinfo_n_way( ic_info );
+	ic_nt    = bli_thrinfo_num_threads( ic_info );
 	pa_info  = bli_thrinfo_sub_node( ic_info );
 	pa_info0 = bli_thrinfo_sub_prenode( ic_info );
 
@@ -341,39 +437,39 @@ void bli_l3_thrinfo_print_trsm_paths
 
 	if ( !pa_info0 ) goto check_header_node;
 
-	pa_way0  = bli_thread_n_way( pa_info0 );
-	pa_nt0   = bli_thread_num_threads( pa_info0 );
+	pa_way0  = bli_thrinfo_n_way( pa_info0 );
+	pa_nt0   = bli_thrinfo_num_threads( pa_info0 );
 	jr_info0 = bli_thrinfo_sub_node( pa_info0 );
 
 	if ( !jr_info0 ) goto check_header_node;
 
-	jr_way0  = bli_thread_n_way( jr_info0 );
-	jr_nt0   = bli_thread_num_threads( jr_info0 );
+	jr_way0  = bli_thrinfo_n_way( jr_info0 );
+	jr_nt0   = bli_thrinfo_num_threads( jr_info0 );
 	ir_info0 = bli_thrinfo_sub_node( jr_info0 );
 
 	if ( !ir_info0 ) goto check_header_node;
 
-	ir_way0  = bli_thread_n_way( ir_info0 );
-	ir_nt0   = bli_thread_num_threads( ir_info0 );
+	ir_way0  = bli_thrinfo_n_way( ir_info0 );
+	ir_nt0   = bli_thrinfo_num_threads( ir_info0 );
 
 	check_header_node:
 
 	if ( !pa_info ) goto print_header;
 
-	pa_way  = bli_thread_n_way( pa_info );
-	pa_nt   = bli_thread_num_threads( pa_info );
+	pa_way  = bli_thrinfo_n_way( pa_info );
+	pa_nt   = bli_thrinfo_num_threads( pa_info );
 	jr_info = bli_thrinfo_sub_node( pa_info );
 
 	if ( !jr_info ) goto print_header;
 
-	jr_way  = bli_thread_n_way( jr_info );
-	jr_nt   = bli_thread_num_threads( jr_info );
+	jr_way  = bli_thrinfo_n_way( jr_info );
+	jr_nt   = bli_thrinfo_num_threads( jr_info );
 	ir_info = bli_thrinfo_sub_node( jr_info );
 
 	if ( !ir_info ) goto print_header;
 
-	ir_way  = bli_thread_n_way( ir_info );
-	ir_nt   = bli_thread_num_threads( ir_info );
+	ir_way  = bli_thrinfo_n_way( ir_info );
+	ir_nt   = bli_thrinfo_num_threads( ir_info );
 
 	print_header:
 
@@ -416,26 +512,26 @@ void bli_l3_thrinfo_print_trsm_paths
 
 		if ( !jc_info ) goto print_thrinfo;
 
-		jc_comm_id = bli_thread_ocomm_id( jc_info );
-		jc_work_id = bli_thread_work_id( jc_info );
+		jc_comm_id = bli_thrinfo_thread_id( jc_info );
+		jc_work_id = bli_thrinfo_work_id( jc_info );
 		pc_info    = bli_thrinfo_sub_node( jc_info );
 
 		if ( !pc_info ) goto print_thrinfo;
 
-		pc_comm_id = bli_thread_ocomm_id( pc_info );
-		pc_work_id = bli_thread_work_id( pc_info );
+		pc_comm_id = bli_thrinfo_thread_id( pc_info );
+		pc_work_id = bli_thrinfo_work_id( pc_info );
 		pb_info    = bli_thrinfo_sub_node( pc_info );
 
 		if ( !pb_info ) goto print_thrinfo;
 
-		pb_comm_id = bli_thread_ocomm_id( pb_info );
-		pb_work_id = bli_thread_work_id( pb_info );
+		pb_comm_id = bli_thrinfo_thread_id( pb_info );
+		pb_work_id = bli_thrinfo_work_id( pb_info );
 		ic_info    = bli_thrinfo_sub_node( pb_info );
 
 		if ( !ic_info ) goto print_thrinfo;
 
-		ic_comm_id = bli_thread_ocomm_id( ic_info );
-		ic_work_id = bli_thread_work_id( ic_info );
+		ic_comm_id = bli_thrinfo_thread_id( ic_info );
+		ic_work_id = bli_thrinfo_work_id( ic_info );
 		pa_info    = bli_thrinfo_sub_node( ic_info );
 		pa_info0   = bli_thrinfo_sub_prenode( ic_info );
 
@@ -443,39 +539,39 @@ void bli_l3_thrinfo_print_trsm_paths
 
 		if ( !pa_info0 ) goto check_thrinfo_node;
 
-		pa_comm_id0 = bli_thread_ocomm_id( pa_info0 );
-		pa_work_id0 = bli_thread_work_id( pa_info0 );
+		pa_comm_id0 = bli_thrinfo_thread_id( pa_info0 );
+		pa_work_id0 = bli_thrinfo_work_id( pa_info0 );
 		jr_info0    = bli_thrinfo_sub_node( pa_info0 );
 
 		if ( !jr_info0 ) goto check_thrinfo_node;
 
-		jr_comm_id0 = bli_thread_ocomm_id( jr_info0 );
-		jr_work_id0 = bli_thread_work_id( jr_info0 );
+		jr_comm_id0 = bli_thrinfo_thread_id( jr_info0 );
+		jr_work_id0 = bli_thrinfo_work_id( jr_info0 );
 		ir_info0    = bli_thrinfo_sub_node( jr_info0 );
 
 		if ( !ir_info0 ) goto check_thrinfo_node;
 
-		ir_comm_id0 = bli_thread_ocomm_id( ir_info0 );
-		ir_work_id0 = bli_thread_work_id( ir_info0 );
+		ir_comm_id0 = bli_thrinfo_thread_id( ir_info0 );
+		ir_work_id0 = bli_thrinfo_work_id( ir_info0 );
 
 		check_thrinfo_node:
 
 		if ( !pa_info ) goto print_thrinfo;
 
-		pa_comm_id = bli_thread_ocomm_id( pa_info );
-		pa_work_id = bli_thread_work_id( pa_info );
+		pa_comm_id = bli_thrinfo_thread_id( pa_info );
+		pa_work_id = bli_thrinfo_work_id( pa_info );
 		jr_info    = bli_thrinfo_sub_node( pa_info );
 
 		if ( !jr_info ) goto print_thrinfo;
 
-		jr_comm_id = bli_thread_ocomm_id( jr_info );
-		jr_work_id = bli_thread_work_id( jr_info );
+		jr_comm_id = bli_thrinfo_thread_id( jr_info );
+		jr_work_id = bli_thrinfo_work_id( jr_info );
 		ir_info    = bli_thrinfo_sub_node( jr_info );
 
 		if ( !ir_info ) goto print_thrinfo;
 
-		ir_comm_id = bli_thread_ocomm_id( ir_info );
-		ir_work_id = bli_thread_work_id( ir_info );
+		ir_comm_id = bli_thrinfo_thread_id( ir_info );
+		ir_work_id = bli_thrinfo_work_id( ir_info );
 
 		print_thrinfo:
 #else
@@ -507,8 +603,8 @@ void bli_l3_thrinfo_print_trsm_paths
 		}
 		else
 		{
-			jc_comm_id = bli_thread_ocomm_id( jc_info );
-			jc_work_id = bli_thread_work_id( jc_info );
+			jc_comm_id = bli_thrinfo_thread_id( jc_info );
+			jc_work_id = bli_thrinfo_work_id( jc_info );
 			pc_info = bli_thrinfo_sub_node( jc_info );
 
 			if ( !pc_info )
@@ -518,8 +614,8 @@ void bli_l3_thrinfo_print_trsm_paths
 			}
 			else
 			{
-				pc_comm_id = bli_thread_ocomm_id( pc_info );
-				pc_work_id = bli_thread_work_id( pc_info );
+				pc_comm_id = bli_thrinfo_thread_id( pc_info );
+				pc_work_id = bli_thrinfo_work_id( pc_info );
 				pb_info = bli_thrinfo_sub_node( pc_info );
 
 				if ( !pb_info )
@@ -529,8 +625,8 @@ void bli_l3_thrinfo_print_trsm_paths
 				}
 				else
 				{
-					pb_comm_id = bli_thread_ocomm_id( pb_info );
-					pb_work_id = bli_thread_work_id( pb_info );
+					pb_comm_id = bli_thrinfo_thread_id( pb_info );
+					pb_work_id = bli_thrinfo_work_id( pb_info );
 					ic_info = bli_thrinfo_sub_node( pb_info );
 
 					if ( !ic_info )
@@ -540,8 +636,8 @@ void bli_l3_thrinfo_print_trsm_paths
 					}
 					else
 					{
-						ic_comm_id = bli_thread_ocomm_id( ic_info );
-						ic_work_id = bli_thread_work_id( ic_info );
+						ic_comm_id = bli_thrinfo_thread_id( ic_info );
+						ic_work_id = bli_thrinfo_work_id( ic_info );
 						pa_info0 = bli_thrinfo_sub_prenode( ic_info );
 						pa_info = bli_thrinfo_sub_node( ic_info );
 
@@ -553,8 +649,8 @@ void bli_l3_thrinfo_print_trsm_paths
 						}
 						else
 						{
-							pa_comm_id0 = bli_thread_ocomm_id( pa_info0 );
-							pa_work_id0 = bli_thread_work_id( pa_info0 );
+							pa_comm_id0 = bli_thrinfo_thread_id( pa_info0 );
+							pa_work_id0 = bli_thrinfo_work_id( pa_info0 );
 							jr_info0 = bli_thrinfo_sub_node( pa_info0 );
 
 							if ( !jr_info0 )
@@ -564,8 +660,8 @@ void bli_l3_thrinfo_print_trsm_paths
 							}
 							else
 							{
-								jr_comm_id0 = bli_thread_ocomm_id( jr_info0 );
-								jr_work_id0 = bli_thread_work_id( jr_info0 );
+								jr_comm_id0 = bli_thrinfo_thread_id( jr_info0 );
+								jr_work_id0 = bli_thrinfo_work_id( jr_info0 );
 								ir_info0 = bli_thrinfo_sub_node( jr_info0 );
 
 								if ( !ir_info0 )
@@ -575,8 +671,8 @@ void bli_l3_thrinfo_print_trsm_paths
 								}
 								else
 								{
-									ir_comm_id0 = bli_thread_ocomm_id( ir_info0 );
-									ir_work_id0 = bli_thread_work_id( ir_info0 );
+									ir_comm_id0 = bli_thrinfo_thread_id( ir_info0 );
+									ir_work_id0 = bli_thrinfo_work_id( ir_info0 );
 								}
 							}
 						}
@@ -589,8 +685,8 @@ void bli_l3_thrinfo_print_trsm_paths
 						}
 						else
 						{
-							pa_comm_id = bli_thread_ocomm_id( pa_info );
-							pa_work_id = bli_thread_work_id( pa_info );
+							pa_comm_id = bli_thrinfo_thread_id( pa_info );
+							pa_work_id = bli_thrinfo_work_id( pa_info );
 							jr_info = bli_thrinfo_sub_node( pa_info );
 
 							if ( !jr_info )
@@ -600,8 +696,8 @@ void bli_l3_thrinfo_print_trsm_paths
 							}
 							else
 							{
-								jr_comm_id = bli_thread_ocomm_id( jr_info );
-								jr_work_id = bli_thread_work_id( jr_info );
+								jr_comm_id = bli_thrinfo_thread_id( jr_info );
+								jr_work_id = bli_thrinfo_work_id( jr_info );
 								ir_info = bli_thrinfo_sub_node( jr_info );
 
 								if ( !ir_info )
@@ -611,8 +707,8 @@ void bli_l3_thrinfo_print_trsm_paths
 								}
 								else
 								{
-									ir_comm_id = bli_thread_ocomm_id( ir_info );
-									ir_work_id = bli_thread_work_id( ir_info );
+									ir_comm_id = bli_thrinfo_thread_id( ir_info );
+									ir_work_id = bli_thrinfo_work_id( ir_info );
 								}
 							}
 						}
@@ -647,15 +743,14 @@ void bli_l3_thrinfo_print_trsm_paths
 
 void bli_l3_thrinfo_free_paths
      (
-       rntm_t*     rntm,
        thrinfo_t** threads
      )
 {
-	dim_t n_threads = bli_thread_num_threads( threads[0] );
+	dim_t n_threads = bli_thrinfo_num_threads( threads[0] );
 	dim_t i;
 
 	for ( i = 0; i < n_threads; ++i )
-		bli_l3_thrinfo_free( rntm, threads[i] );
+		bli_thrinfo_free( threads[i] );
 
 	bli_free_intl( threads );
 }
