@@ -36,56 +36,58 @@
 
 void bli_gemm_blk_var3
      (
-       obj_t*  a,
-       obj_t*  b,
-       obj_t*  c,
-       cntx_t* cntx,
-       rntm_t* rntm,
-       cntl_t* cntl,
-       thrinfo_t* thread
+       const obj_t*     a,
+       const obj_t*     b,
+       const obj_t*     c,
+       const cntx_t*    cntx,
+       const cntl_t*    cntl,
+             thrinfo_t* thread_par
      )
 {
-	obj_t a1, b1;
-	dim_t b_alg;
+	obj_t ap, bp, cs;
+	bli_obj_alias_to( a, &ap );
+	bli_obj_alias_to( b, &bp );
+	bli_obj_alias_to( c, &cs );
+
+	thrinfo_t* thread = bli_thrinfo_sub_node( thread_par );
 
 	// Determine the direction in which to partition (forwards or backwards).
-	dir_t direct = bli_l3_direct( a, b, c, cntl );
+	dir_t direct = bli_l3_direct( &ap, &bp, &cs, cntl );
 
 	// Prune any zero region that exists along the partitioning dimension.
-	bli_l3_prune_unref_mparts_k( a, b, c, cntl );
+	bli_l3_prune_unref_mparts_k( &ap, &bp, &cs, cntl );
 
 	// Query dimension in partitioning direction.
-	dim_t k_trans = bli_obj_width_after_trans( a );
+	dim_t k_trans = bli_obj_width_after_trans( &ap );
 
 	// Partition along the k dimension.
+	dim_t b_alg;
 	for ( dim_t i = 0; i < k_trans; i += b_alg )
 	{
 		// Determine the current algorithmic blocksize.
-		b_alg = bli_l3_determine_kc( direct, i, k_trans, a, b,
+		b_alg = bli_l3_determine_kc( direct, i, k_trans, &ap, &bp,
 		                             bli_cntl_bszid( cntl ), cntx, cntl );
 
 		// Acquire partitions for A1 and B1.
+		obj_t a1, b1;
 		bli_acquire_mpart_ndim( direct, BLIS_SUBPART1,
-		                        i, b_alg, a, &a1 );
+		                        i, b_alg, &ap, &a1 );
 		bli_acquire_mpart_mdim( direct, BLIS_SUBPART1,
-		                        i, b_alg, b, &b1 );
+		                        i, b_alg, &bp, &b1 );
 
 		// Perform gemm subproblem.
-		bli_gemm_int
+		bli_l3_int
 		(
 		  &BLIS_ONE,
 		  &a1,
 		  &b1,
 		  &BLIS_ONE,
-		  c,
+		  &cs,
 		  cntx,
-		  rntm,
 		  bli_cntl_sub_node( cntl ),
-		  bli_thrinfo_sub_node( thread )
+		  thread
 		);
 
-		bli_thread_obarrier( bli_thrinfo_sub_node( thread ) );
-
 		// This variant executes multiple rank-k updates. Therefore, if the
 		// internal beta scalar on matrix C is non-zero, we must use it
 		// only for the first iteration (and then BLIS_ONE for all others).
@@ -93,7 +95,7 @@ void bli_gemm_blk_var3
 		// can simply overwrite the internal beta scalar with BLIS_ONE once
 		// it has been used in the first iteration. However...
 
-		// Unlike variant 3 of gemm and herk, which reset the internal scalar
+		// Unlike variant 3 of gemm and gemmt, which reset the internal scalar
 		// on C at the end of the first iteration so that subsequent iterations
 		// do not erroneously apply beta more than once, it is important that
 		// this behavior not be applied to trmm. That is because the order of
@@ -107,7 +109,7 @@ void bli_gemm_blk_var3
 		// Thus, for neither trmm nor trmm3 should we reset the scalar on C
 		// after the first iteration.
 		if ( bli_cntl_family( cntl ) != BLIS_TRMM )
-		if ( i == 0 ) bli_obj_scalar_reset( c );
+		if ( i == 0 ) bli_obj_scalar_reset( &cs );
 	}
 }
 
