@@ -35,43 +35,37 @@
 
 cntl_t* bli_gemm_cntl_create
      (
-       rntm_t* rntm,
+       pool_t* pool,
        opid_t  family,
        pack_t  schema_a,
-       pack_t  schema_b
+       pack_t  schema_b,
+       void_fp ker
      );
 
 // -----------------------------------------------------------------------------
 
 cntl_t* bli_gemmbp_cntl_create
      (
-       rntm_t* rntm,
+       pool_t* pool,
        opid_t  family,
        pack_t  schema_a,
-       pack_t  schema_b
+       pack_t  schema_b,
+       void_fp ker
      );
 
-#if 0
-cntl_t* bli_gemmpb_cntl_create
-     (
-       opid_t family,
-     );
-#endif
-
 // -----------------------------------------------------------------------------
 
 void bli_gemm_cntl_free
      (
-       rntm_t*    rntm,
-       cntl_t*    cntl,
-       thrinfo_t* thread
+       pool_t* pool,
+       cntl_t* cntl
      );
 
 // -----------------------------------------------------------------------------
 
 cntl_t* bli_gemm_cntl_create_node
      (
-       rntm_t* rntm,
+       pool_t* pool,
        opid_t  family,
        bszid_t bszid,
        void_fp var_func,
