@@ -37,35 +37,33 @@
 
 cntl_t* bli_trsm_cntl_create
      (
-       rntm_t* rntm,
+       pool_t* pool,
        side_t  side,
        pack_t  schema_a,
-       pack_t  schema_b
+       pack_t  schema_b,
+       void_fp ker
      )
 {
 	if ( bli_is_left( side ) )
-		return bli_trsm_l_cntl_create( rntm, schema_a, schema_b );
+		return bli_trsm_l_cntl_create( pool, schema_a, schema_b, ker );
 	else
-		return bli_trsm_r_cntl_create( rntm, schema_a, schema_b );
+		return bli_trsm_r_cntl_create( pool, schema_a, schema_b, ker );
 }
 
 cntl_t* bli_trsm_l_cntl_create
      (
-       rntm_t* rntm,
+       pool_t* pool,
        pack_t  schema_a,
-       pack_t  schema_b
+       pack_t  schema_b,
+       void_fp ker
      )
 {
 	void_fp macro_kernel_p;
-	void_fp packa_fp;
-	void_fp packb_fp;
 
-	// Use the function pointer to the macrokernels that use slab
-	// assignment of micropanels to threads in the jr and ir loops.
+	// Set the default macrokernel. If a non-NULL kernel function pointer is
+	// passed in, we use that instead.
 	macro_kernel_p = bli_trsm_xx_ker_var2;
-
-	packa_fp = bli_packm_blk_var1;
-	packb_fp = bli_packm_blk_var1;
+	if ( ker ) macro_kernel_p = ker;
 
 	const opid_t family = BLIS_TRSM;
 
@@ -75,18 +73,18 @@ cntl_t* bli_trsm_l_cntl_create
 
 	cntl_t* gemm_cntl_bu_ke = bli_trsm_cntl_create_node
 	(
-	  rntm,    // the thread's runtime structure
-	  family,  // the operation family
-	  BLIS_MR, // needed for bli_thrinfo_rgrow()
-	  NULL,    // variant function pointer not used
-	  NULL     // no sub-node; this is the leaf of the tree.
+	  pool,         // the thread's sba pool
+	  family,       // the operation family
+	  BLIS_MR,
+	  NULL,         // variant function pointer not used
+	  NULL          // no sub-node; this is the leaf of the tree.
 	);
 
 	cntl_t* gemm_cntl_bp_bu = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
-	  BLIS_NR, // not used by macro-kernel, but needed for bli_thrinfo_rgrow()
+	  BLIS_NR,
 	  macro_kernel_p,
 	  gemm_cntl_bu_ke
 	);
@@ -94,15 +92,14 @@ cntl_t* bli_trsm_l_cntl_create
 	// Create a node for packing matrix A.
 	cntl_t* gemm_cntl_packa = bli_packm_cntl_create_node
 	(
-	  rntm,
-	  bli_trsm_packa, // trsm operation's packm function for A.
-	  packa_fp,
+	  pool,
+	  bli_l3_packa, // trsm operation's packm function for A.
 	  BLIS_MR,
 	  BLIS_MR,
-	  FALSE,   // do NOT invert diagonal
-	  TRUE,    // reverse iteration if upper?
-	  FALSE,   // reverse iteration if lower?
-	  schema_a, // normally BLIS_PACKED_ROW_PANELS
+	  FALSE,        // do NOT invert diagonal
+	  TRUE,         // reverse iteration if upper?
+	  FALSE,        // reverse iteration if lower?
+	  schema_a,     // normally BLIS_PACKED_ROW_PANELS
 	  BLIS_BUFFER_FOR_A_BLOCK,
 	  gemm_cntl_bp_bu
 	);
@@ -113,18 +110,18 @@ cntl_t* bli_trsm_l_cntl_create
 
 	cntl_t* trsm_cntl_bu_ke = bli_trsm_cntl_create_node
 	(
-	  rntm,    // the thread's runtime structure
-	  family,  // the operation family
-	  BLIS_MR, // needed for bli_thrinfo_rgrow()
-	  NULL,    // variant function pointer not used
-	  NULL     // no sub-node; this is the leaf of the tree.
+	  pool,         // the thread's sba pool
+	  family,       // the operation family
+	  BLIS_MR,
+	  NULL,         // variant function pointer not used
+	  NULL          // no sub-node; this is the leaf of the tree.
 	);
 
 	cntl_t* trsm_cntl_bp_bu = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
-	  BLIS_NR, // not used by macro-kernel, but needed for bli_thrinfo_rgrow()
+	  BLIS_NR,
 	  macro_kernel_p,
 	  trsm_cntl_bu_ke
 	);
@@ -132,19 +129,18 @@ cntl_t* bli_trsm_l_cntl_create
 	// Create a node for packing matrix A.
 	cntl_t* trsm_cntl_packa = bli_packm_cntl_create_node
 	(
-	  rntm,
-	  bli_trsm_packa, // trsm operation's packm function for A.
-	  packa_fp,
+	  pool,
+	  bli_l3_packa, // trsm operation's packm function for A.
 	  BLIS_MR,
 	  BLIS_MR,
 #ifdef BLIS_ENABLE_TRSM_PREINVERSION
-	  TRUE,    // invert diagonal
+	  TRUE,         // invert diagonal
 #else
-	  FALSE,   // do NOT invert diagonal
+	  FALSE,        // do NOT invert diagonal
 #endif
-	  TRUE,    // reverse iteration if upper?
-	  FALSE,   // reverse iteration if lower?
-	  schema_a, // normally BLIS_PACKED_ROW_PANELS
+	  TRUE,         // reverse iteration if upper?
+	  FALSE,        // reverse iteration if lower?
+	  schema_a,     // normally BLIS_PACKED_ROW_PANELS
 	  BLIS_BUFFER_FOR_A_BLOCK,
 	  trsm_cntl_bp_bu
 	);
@@ -155,7 +151,7 @@ cntl_t* bli_trsm_l_cntl_create
 	// NOTE: We attach the gemm sub-tree as the main branch.
 	cntl_t* trsm_cntl_op_bp = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_MC,
 	  bli_trsm_blk_var1,
@@ -170,15 +166,14 @@ cntl_t* bli_trsm_l_cntl_create
 	// Create a node for packing matrix B.
 	cntl_t* trsm_cntl_packb = bli_packm_cntl_create_node
 	(
-	  rntm,
-	  bli_trsm_packb,
-	  packb_fp,
-	  BLIS_MR,
+	  pool,
+	  bli_l3_packb,
 	  BLIS_NR,
-	  FALSE,   // do NOT invert diagonal
-	  FALSE,   // reverse iteration if upper?
-	  FALSE,   // reverse iteration if lower?
-	  schema_b, // normally BLIS_PACKED_COL_PANELS
+	  BLIS_MR,
+	  FALSE,        // do NOT invert diagonal
+	  FALSE,        // reverse iteration if upper?
+	  FALSE,        // reverse iteration if lower?
+	  schema_b,     // normally BLIS_PACKED_COL_PANELS
 	  BLIS_BUFFER_FOR_B_PANEL,
 	  trsm_cntl_op_bp
 	);
@@ -186,7 +181,7 @@ cntl_t* bli_trsm_l_cntl_create
 	// Create a node for partitioning the k dimension by KC.
 	cntl_t* trsm_cntl_mm_op = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_KC,
 	  bli_trsm_blk_var3,
@@ -196,7 +191,7 @@ cntl_t* bli_trsm_l_cntl_create
 	// Create a node for partitioning the n dimension by NC.
 	cntl_t* trsm_cntl_vl_mm = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_NC,
 	  bli_trsm_blk_var2,
@@ -208,23 +203,24 @@ cntl_t* bli_trsm_l_cntl_create
 
 cntl_t* bli_trsm_r_cntl_create
      (
-	   rntm_t* rntm,
+       pool_t* pool,
        pack_t  schema_a,
-       pack_t  schema_b
+       pack_t  schema_b,
+       void_fp ker
      )
 {
 	// NOTE: trsm macrokernels are presently disabled for right-side execution.
+	// Set the default macrokernel. If a non-NULL kernel function pointer is
+	// passed in, we use that instead.
 	void_fp macro_kernel_p = bli_trsm_xx_ker_var2;
-
-	void_fp packa_fp = bli_packm_blk_var1;
-	void_fp packb_fp = bli_packm_blk_var1;
+	if ( ker ) macro_kernel_p = ker;
 
 	const opid_t family = BLIS_TRSM;
 
 	// Create two nodes for the macro-kernel.
 	cntl_t* trsm_cntl_bu_ke = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_MR, // needed for bli_thrinfo_rgrow()
 	  NULL,    // variant function pointer not used
@@ -233,7 +229,7 @@ cntl_t* bli_trsm_r_cntl_create
 
 	cntl_t* trsm_cntl_bp_bu = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_NR, // not used by macro-kernel, but needed for bli_thrinfo_rgrow()
 	  macro_kernel_p,
@@ -243,9 +239,8 @@ cntl_t* bli_trsm_r_cntl_create
 	// Create a node for packing matrix A.
 	cntl_t* trsm_cntl_packa = bli_packm_cntl_create_node
 	(
-	  rntm,
-	  bli_trsm_packa,
-	  packa_fp,
+	  pool,
+	  bli_l3_packa,
 	  BLIS_NR,
 	  BLIS_MR,
 	  FALSE,   // do NOT invert diagonal
@@ -259,7 +254,7 @@ cntl_t* bli_trsm_r_cntl_create
 	// Create a node for partitioning the m dimension by MC.
 	cntl_t* trsm_cntl_op_bp = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_MC,
 	  bli_trsm_blk_var1,
@@ -269,9 +264,8 @@ cntl_t* bli_trsm_r_cntl_create
 	// Create a node for packing matrix B.
 	cntl_t* trsm_cntl_packb = bli_packm_cntl_create_node
 	(
-	  rntm,
-	  bli_trsm_packb,
-	  packb_fp,
+	  pool,
+	  bli_l3_packb,
 	  BLIS_MR,
 	  BLIS_MR,
 	  TRUE,    // do NOT invert diagonal
@@ -285,7 +279,7 @@ cntl_t* bli_trsm_r_cntl_create
 	// Create a node for partitioning the k dimension by KC.
 	cntl_t* trsm_cntl_mm_op = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_KC,
 	  bli_trsm_blk_var3,
@@ -295,7 +289,7 @@ cntl_t* bli_trsm_r_cntl_create
 	// Create a node for partitioning the n dimension by NC.
 	cntl_t* trsm_cntl_vl_mm = bli_trsm_cntl_create_node
 	(
-	  rntm,
+	  pool,
 	  family,
 	  BLIS_NC,
 	  bli_trsm_blk_var2,
@@ -307,25 +301,24 @@ cntl_t* bli_trsm_r_cntl_create
 
 void bli_trsm_cntl_free
      (
-       rntm_t*    rntm,
-       cntl_t*    cntl,
-       thrinfo_t* thread
+       pool_t* pool,
+       cntl_t* cntl
      )
 {
-	bli_cntl_free( rntm, cntl, thread );
+	bli_cntl_free( pool, cntl );
 }
 
 // -----------------------------------------------------------------------------
 
 cntl_t* bli_trsm_cntl_create_node
      (
-       rntm_t* rntm,
+       pool_t* pool,
        opid_t  family,
        bszid_t bszid,
        void_fp var_func,
        cntl_t* sub_node
      )
 {
-	return bli_cntl_create_node( rntm, family, bszid, var_func, NULL, sub_node );
+	return bli_cntl_create_node( pool, family, bszid, var_func, NULL, sub_node );
 }
 
