@@ -179,7 +179,7 @@ void PASTEMAC(ch,varname) \
 	ctype           ct[ BLIS_STACK_BUF_MAX_SIZE \
 	                    / sizeof( ctype ) ] \
 	                    __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const bool      col_pref    = bli_cntx_l3_vir_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
+	const bool      col_pref    = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_VIR_UKR, cntx ); \
 	const inc_t     rs_ct       = ( col_pref ? 1 : NR ); \
 	const inc_t     cs_ct       = ( col_pref ? MR : 1 ); \
 \
@@ -411,7 +411,7 @@ void PASTEMAC(ch,varname) \
 					a2 = a_cast; \
 					b2 = b1; \
 					/*if ( bli_is_last_iter( j, n_iter, 0, 1 ) ) */\
-					if ( j + bli_thread_num_threads(thread) >= n_iter ) \
+					if ( j + bli_thrinfo_num_threads(thread) >= n_iter ) \
 						b2 = b_cast; \
 				} \
 \
@@ -476,7 +476,7 @@ void PASTEMAC(ch,varname) \
 					a2 = a_cast; \
 					b2 = b1; \
 					/*if ( bli_is_last_iter( j, n_iter, 0, 1 ) ) */\
-					if ( j + bli_thread_num_threads(thread) >= n_iter ) \
+					if ( j + bli_thrinfo_num_threads(thread) >= n_iter ) \
 						b2 = b_cast; \
 				} \
 \
