@@ -184,7 +184,7 @@ void PASTEMAC(ch,varname) \
 	ctype           ct[ BLIS_STACK_BUF_MAX_SIZE \
 	                    / sizeof( ctype ) ] \
 	                    __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const bool_t    col_pref    = bli_cntx_l3_vir_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
+	const bool      col_pref    = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_VIR_UKR, cntx ); \
 	const inc_t     rs_ct       = ( col_pref ? 1 : NR ); \
 	const inc_t     cs_ct       = ( col_pref ? MR : 1 ); \
 \
@@ -436,7 +436,7 @@ void PASTEMAC(ch,varname) \
 				/* Compute the addresses of the next panels of A and B. */ \
 				a2 = a1; \
 				/*if ( bli_is_last_iter( i, m_iter, 0, 1 ) ) */\
-				if ( i + bli_thread_num_threads(thread) >= m_iter ) \
+				if ( i + bli_thrinfo_num_threads(thread) >= m_iter ) \
 				{ \
 					a2 = a_cast; \
 					b2 = b1 + ps_b_cur; \
@@ -516,7 +516,7 @@ void PASTEMAC(ch,varname) \
 				/* Compute the addresses of the next panels of A and B. */ \
 				a2 = a1; \
 				/*if ( bli_is_last_iter( i, m_iter, 0, 1 ) ) */\
-				if ( i + bli_thread_num_threads(thread) >= m_iter ) \
+				if ( i + bli_thrinfo_num_threads(thread) >= m_iter ) \
 				{ \
 					a2 = a_cast; \
 					b2 = b1 + cstep_b; \
