@@ -38,48 +38,50 @@
 
 // auxinfo_t field query
 
-BLIS_INLINE pack_t bli_auxinfo_schema_a( auxinfo_t* ai )
+BLIS_INLINE pack_t bli_auxinfo_schema_a( const auxinfo_t* ai )
 {
 	return ai->schema_a;
 }
-BLIS_INLINE pack_t bli_auxinfo_schema_b( auxinfo_t* ai )
+BLIS_INLINE pack_t bli_auxinfo_schema_b( const auxinfo_t* ai )
 {
 	return ai->schema_b;
 }
 
-BLIS_INLINE void* bli_auxinfo_next_a( auxinfo_t* ai )
+BLIS_INLINE const void* bli_auxinfo_next_a( const auxinfo_t* ai )
 {
 	return ai->a_next;
 }
-BLIS_INLINE void* bli_auxinfo_next_b( auxinfo_t* ai )
+BLIS_INLINE const void* bli_auxinfo_next_b( const auxinfo_t* ai )
 {
 	return ai->b_next;
 }
 
-BLIS_INLINE inc_t bli_auxinfo_is_a( auxinfo_t* ai )
+BLIS_INLINE inc_t bli_auxinfo_is_a( const auxinfo_t* ai )
 {
 	return ai->is_a;
 }
-BLIS_INLINE inc_t bli_auxinfo_is_b( auxinfo_t* ai )
+BLIS_INLINE inc_t bli_auxinfo_is_b( const auxinfo_t* ai )
 {
 	return ai->is_b;
 }
 
-BLIS_INLINE inc_t bli_auxinfo_ps_a( auxinfo_t* ai )
+BLIS_INLINE inc_t bli_auxinfo_ps_a( const auxinfo_t* ai )
 {
 	return ai->ps_a;
 }
-BLIS_INLINE inc_t bli_auxinfo_ps_b( auxinfo_t* ai )
+BLIS_INLINE inc_t bli_auxinfo_ps_b( const auxinfo_t* ai )
 {
 	return ai->ps_b;
 }
 
-#if 0
-BLIS_INLINE inc_t bli_auxinfo_dt_on_output( auxinfo_t* ai )
+BLIS_INLINE void_fp bli_auxinfo_ukr( const auxinfo_t* ai )
 {
-	return ai->dt_on_output;
+	return ai->ukr;
+}
+BLIS_INLINE const void* bli_auxinfo_params( const auxinfo_t* ai )
+{
+	return ai->params;
 }
-#endif
 
 
 // auxinfo_t field modification
@@ -93,15 +95,15 @@ BLIS_INLINE void bli_auxinfo_set_schema_b( pack_t schema, auxinfo_t* ai )
 	ai->schema_b = schema;
 }
 
-BLIS_INLINE void bli_auxinfo_set_next_a( void* p, auxinfo_t* ai )
+BLIS_INLINE void bli_auxinfo_set_next_a( const void* p, auxinfo_t* ai )
 {
 	ai->a_next = p;
 }
-BLIS_INLINE void bli_auxinfo_set_next_b( void* p, auxinfo_t* ai )
+BLIS_INLINE void bli_auxinfo_set_next_b( const void* p, auxinfo_t* ai )
 {
 	ai->b_next = p;
 }
-BLIS_INLINE void bli_auxinfo_set_next_ab( void* ap, void* bp, auxinfo_t* ai )
+BLIS_INLINE void bli_auxinfo_set_next_ab( const void* ap, const void* bp, auxinfo_t* ai )
 {
 	ai->a_next = ap;
 	ai->b_next = bp;
@@ -125,12 +127,14 @@ BLIS_INLINE void bli_auxinfo_set_ps_b( inc_t ps, auxinfo_t* ai )
 	ai->ps_b = ps;
 }
 
-#if 0
-BLIS_INLINE void bli_auxinfo_set_dt_on_output( num_t dt_on_output, auxinfo_t* ai )
+BLIS_INLINE void bli_auxinfo_set_ukr( void_fp ukr, auxinfo_t* ai )
 {
-	ai->dt_on_output = dt_on_output;
+	ai->ukr = ukr;
 }
+BLIS_INLINE void bli_auxinfo_set_params( const void* params, auxinfo_t* ai )
+{
+	ai->params = params;
+}
+
 #endif
 
-#endif 
-
