@@ -37,7 +37,7 @@
 
 // -- General stuff ------------------------------------------------------------
 
-err_t bli_check_error_code_helper( gint_t code, char* file, guint_t line )
+err_t bli_check_error_code_helper( gint_t code, const char* file, guint_t line )
 {
 	if ( code == BLIS_SUCCESS ) return code;
 
@@ -68,7 +68,7 @@ err_t bli_check_valid_error_level( errlev_t level )
 	return e_val;
 }
 
-err_t bli_check_null_pointer( void* ptr )
+err_t bli_check_null_pointer( const void* ptr )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -128,7 +128,7 @@ err_t bli_check_valid_diag( diag_t diag )
 	return e_val;
 }
 
-err_t bli_check_nonunit_diag( obj_t* a )
+err_t bli_check_nonunit_diag( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -155,7 +155,7 @@ err_t bli_check_valid_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_object_valid_datatype( obj_t* a )
+err_t bli_check_object_valid_datatype( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -176,7 +176,7 @@ err_t bli_check_noninteger_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_noninteger_object( obj_t* a )
+err_t bli_check_noninteger_object( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -197,7 +197,7 @@ err_t bli_check_nonconstant_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_nonconstant_object( obj_t* a )
+err_t bli_check_nonconstant_object( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -221,7 +221,7 @@ err_t bli_check_floating_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_floating_object( obj_t* a )
+err_t bli_check_floating_object( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -243,7 +243,7 @@ err_t bli_check_real_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_real_object( obj_t* a )
+err_t bli_check_real_object( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -264,7 +264,7 @@ err_t bli_check_integer_datatype( num_t dt )
 	return e_val;
 }
 
-err_t bli_check_integer_object( obj_t* a )
+err_t bli_check_integer_object( const obj_t* a )
 {
 	err_t e_val;
 	num_t dt;
@@ -287,7 +287,7 @@ err_t bli_check_consistent_datatypes( num_t dt_a, num_t dt_b )
 	return e_val;
 }
 
-err_t bli_check_consistent_object_datatypes( obj_t* a, obj_t* b )
+err_t bli_check_consistent_object_datatypes( const obj_t* a, const obj_t* b )
 {
 	err_t e_val;
 	num_t dt_a;
@@ -315,7 +315,7 @@ err_t bli_check_datatype_real_proj_of( num_t dt_c, num_t dt_r )
 	return e_val;
 }
 
-err_t bli_check_object_real_proj_of( obj_t* c, obj_t* r )
+err_t bli_check_object_real_proj_of( const obj_t* c, const obj_t* r )
 {
 	err_t e_val;
 	num_t dt_c;
@@ -329,7 +329,7 @@ err_t bli_check_object_real_proj_of( obj_t* c, obj_t* r )
 	return e_val;
 }
 
-err_t bli_check_real_valued_object( obj_t* a )
+err_t bli_check_real_valued_object( const obj_t* a )
 {
 	err_t  e_val = BLIS_SUCCESS;
 	double a_real;
@@ -363,7 +363,7 @@ err_t bli_check_consistent_precisions( num_t dt_a, num_t dt_b )
 	return e_val;
 }
 
-err_t bli_check_consistent_object_precisions( obj_t* a, obj_t* b )
+err_t bli_check_consistent_object_precisions( const obj_t* a, const obj_t* b )
 {
 	err_t e_val;
 	num_t dt_a;
@@ -379,7 +379,7 @@ err_t bli_check_consistent_object_precisions( obj_t* a, obj_t* b )
 
 // -- Dimension-related checks -------------------------------------------------
 
-err_t bli_check_conformal_dims( obj_t* a, obj_t* b )
+err_t bli_check_conformal_dims( const obj_t* a, const obj_t* b )
 {
 	err_t e_val = BLIS_SUCCESS;
 	dim_t m_a, n_a;
@@ -396,7 +396,7 @@ err_t bli_check_conformal_dims( obj_t* a, obj_t* b )
 	return e_val;
 }
 
-err_t bli_check_level3_dims( obj_t* a, obj_t* b, obj_t* c )
+err_t bli_check_level3_dims( const obj_t* a, const obj_t* b, const obj_t* c )
 {
 	err_t e_val = BLIS_SUCCESS;
 	dim_t m_c, n_c;
@@ -420,7 +420,7 @@ err_t bli_check_level3_dims( obj_t* a, obj_t* b, obj_t* c )
 	return e_val;
 }
 
-err_t bli_check_scalar_object( obj_t* a )
+err_t bli_check_scalar_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -435,7 +435,7 @@ err_t bli_check_scalar_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_vector_object( obj_t* a )
+err_t bli_check_vector_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -449,7 +449,7 @@ err_t bli_check_vector_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_matrix_object( obj_t* a )
+err_t bli_check_matrix_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -460,7 +460,7 @@ err_t bli_check_matrix_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_equal_vector_lengths( obj_t* x, obj_t* y )
+err_t bli_check_equal_vector_lengths( const obj_t* x, const obj_t* y )
 {
 	err_t e_val = BLIS_SUCCESS;
 	dim_t dim_x;
@@ -475,7 +475,7 @@ err_t bli_check_equal_vector_lengths( obj_t* x, obj_t* y )
 	return e_val;
 }
 
-err_t bli_check_square_object( obj_t* a )
+err_t bli_check_square_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -485,7 +485,7 @@ err_t bli_check_square_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_object_length_equals( obj_t* a, dim_t m )
+err_t bli_check_object_length_equals( const obj_t* a, dim_t m )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -495,7 +495,7 @@ err_t bli_check_object_length_equals( obj_t* a, dim_t m )
 	return e_val;
 }
 
-err_t bli_check_object_width_equals( obj_t* a, dim_t n )
+err_t bli_check_object_width_equals( const obj_t* a, dim_t n )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -505,7 +505,7 @@ err_t bli_check_object_width_equals( obj_t* a, dim_t n )
 	return e_val;
 }
 
-err_t bli_check_vector_dim_equals( obj_t* a, dim_t n )
+err_t bli_check_vector_dim_equals( const obj_t* a, dim_t n )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -515,7 +515,7 @@ err_t bli_check_vector_dim_equals( obj_t* a, dim_t n )
 	return e_val;
 }
 
-err_t bli_check_object_diag_offset_equals( obj_t* a, doff_t offset )
+err_t bli_check_object_diag_offset_equals( const obj_t* a, doff_t offset )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -612,7 +612,7 @@ err_t bli_check_matrix_strides( dim_t m, dim_t n, inc_t rs, inc_t cs, inc_t is )
 
 // -- Structure-related checks -------------------------------------------------
 
-err_t bli_check_general_object( obj_t* a )
+err_t bli_check_general_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -622,7 +622,7 @@ err_t bli_check_general_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_hermitian_object( obj_t* a )
+err_t bli_check_hermitian_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -632,7 +632,7 @@ err_t bli_check_hermitian_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_symmetric_object( obj_t* a )
+err_t bli_check_symmetric_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -642,7 +642,7 @@ err_t bli_check_symmetric_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_triangular_object( obj_t* a )
+err_t bli_check_triangular_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -652,7 +652,7 @@ err_t bli_check_triangular_object( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_object_struc( obj_t* a, struc_t struc )
+err_t bli_check_object_struc( const obj_t* a, struc_t struc )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -666,7 +666,7 @@ err_t bli_check_object_struc( obj_t* a, struc_t struc )
 
 // -- Storage-related checks ---------------------------------------------------
 
-err_t bli_check_upper_or_lower_object( obj_t* a )
+err_t bli_check_upper_or_lower_object( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -731,7 +731,7 @@ err_t bli_check_valid_3x3_subpart( subpart_t part )
 
 // -- Control tree-related checks ----------------------------------------------
 
-err_t bli_check_valid_cntl( void* cntl )
+err_t bli_check_valid_cntl( const void* cntl )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -743,7 +743,7 @@ err_t bli_check_valid_cntl( void* cntl )
 
 // -- Packing-related checks ---------------------------------------------------
 
-err_t bli_check_packm_schema_on_unpack( obj_t* a )
+err_t bli_check_packm_schema_on_unpack( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -756,7 +756,7 @@ err_t bli_check_packm_schema_on_unpack( obj_t* a )
 	return e_val;
 }
 
-err_t bli_check_packv_schema_on_unpack( obj_t* a )
+err_t bli_check_packv_schema_on_unpack( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -768,7 +768,7 @@ err_t bli_check_packv_schema_on_unpack( obj_t* a )
 
 // -- Buffer-related checks ----------------------------------------------------
 
-err_t bli_check_object_buffer( obj_t* a )
+err_t bli_check_object_buffer( const obj_t* a )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -783,7 +783,7 @@ err_t bli_check_object_buffer( obj_t* a )
 
 // -- Memory checks ------------------------------------------------------------
 
-err_t bli_check_valid_malloc_buf( void* ptr )
+err_t bli_check_valid_malloc_buf( const void* ptr )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -809,7 +809,7 @@ err_t bli_check_valid_packbuf( packbuf_t buf_type )
 	return e_val;
 }
 
-err_t bli_check_if_exhausted_pool( pool_t* pool )
+err_t bli_check_if_exhausted_pool( const pool_t* pool )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -819,22 +819,26 @@ err_t bli_check_if_exhausted_pool( pool_t* pool )
 	return e_val;
 }
 
-err_t bli_check_sufficient_stack_buf_size( num_t dt, cntx_t* cntx )
+err_t bli_check_sufficient_stack_buf_size( const cntx_t* cntx )
 {
 	err_t e_val = BLIS_SUCCESS;
+	num_t dt;
 
-	dim_t mr      = bli_cntx_get_blksz_def_dt( dt, BLIS_MR, cntx );
-	dim_t nr      = bli_cntx_get_blksz_def_dt( dt, BLIS_NR, cntx );
-	siz_t dt_size = bli_dt_size( dt );
+	for ( dt = BLIS_DT_LO; dt <= BLIS_DT_HI; ++dt )
+	{
+		dim_t mr      = bli_cntx_get_blksz_def_dt( dt, BLIS_MR, cntx );
+		dim_t nr      = bli_cntx_get_blksz_def_dt( dt, BLIS_NR, cntx );
+		siz_t dt_size = bli_dt_size( dt );
 
-	// NOTE: For induced methods, we use the size of the complex datatypes
-	// (rather than the size of the native micro-kernels' datatype) because
-	// the macro-kernel needs this larger micro-tile footprint, even if the
-	// virtual micro-kernel implementation will only ever be writing to half
-	// of it (real or imaginary part) at a time.
+		// NOTE: For induced methods, we use the size of the complex datatypes
+		// (rather than the size of the native micro-kernels' datatype) because
+		// the macro-kernel needs this larger micro-tile footprint, even if the
+		// virtual micro-kernel implementation will only ever be writing to half
+		// of it (real or imaginary part) at a time.
 
-	if ( mr * nr * dt_size > BLIS_STACK_BUF_MAX_SIZE )
-		e_val = BLIS_INSUFFICIENT_STACK_BUF_SIZE;
+		if ( mr * nr * dt_size > BLIS_STACK_BUF_MAX_SIZE )
+			e_val = BLIS_INSUFFICIENT_STACK_BUF_SIZE;
+	}
 
 	return e_val;
 }
@@ -869,7 +873,7 @@ err_t bli_check_alignment_is_mult_of_ptr_size( size_t align_size )
 
 // -- Object-related errors ----------------------------------------------------
 
-err_t bli_check_object_alias_of( obj_t* a, obj_t* b )
+err_t bli_check_object_alias_of( const obj_t* a, const obj_t* b )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -891,7 +895,7 @@ err_t bli_check_valid_arch_id( arch_t id )
 	return e_val;
 }
 
-err_t bli_check_initialized_gks_cntx( cntx_t** cntx )
+err_t bli_check_initialized_gks_cntx( const cntx_t* const * cntx )
 {
 	err_t e_val = BLIS_SUCCESS;
 
@@ -903,7 +907,7 @@ err_t bli_check_initialized_gks_cntx( cntx_t** cntx )
 
 // -- Architecture-related errors ----------------------------------------------
 
-err_t bli_check_valid_mc_mod_mult( blksz_t* mc, blksz_t* mr )
+err_t bli_check_valid_mc_mod_mult( const blksz_t* mc, const blksz_t* mr )
 {
 	num_t dt;
 
@@ -920,7 +924,7 @@ err_t bli_check_valid_mc_mod_mult( blksz_t* mc, blksz_t* mr )
 	return BLIS_SUCCESS;
 }
 
-err_t bli_check_valid_nc_mod_mult( blksz_t* nc, blksz_t* nr )
+err_t bli_check_valid_nc_mod_mult( const blksz_t* nc, const blksz_t* nr )
 {
 	num_t dt;
 
@@ -937,7 +941,7 @@ err_t bli_check_valid_nc_mod_mult( blksz_t* nc, blksz_t* nr )
 	return BLIS_SUCCESS;
 }
 
-err_t bli_check_valid_kc_mod_mult( blksz_t* kc, blksz_t* kr )
+err_t bli_check_valid_kc_mod_mult( const blksz_t* kc, const blksz_t* kr )
 {
 	num_t dt;
 
