@@ -37,7 +37,7 @@
 
 cntl_t* bli_cntl_create_node
      (
-       rntm_t* rntm,
+       pool_t* sba_pool,
        opid_t  family,
        bszid_t bszid,
        void_fp var_func,
@@ -46,14 +46,13 @@ cntl_t* bli_cntl_create_node
      )
 {
 	cntl_t* cntl;
-	mem_t*  pack_mem;
 
 	#ifdef BLIS_ENABLE_MEM_TRACING
 	printf( "bli_cntl_create_node(): " );
 	#endif
 
 	// Allocate the cntl_t struct.
-	cntl = bli_sba_acquire( rntm, sizeof( cntl_t ) );
+	cntl = bli_sba_acquire( sba_pool, sizeof( cntl_t ) );
 
 	bli_cntl_set_family( family, cntl );
 	bli_cntl_set_bszid( bszid, cntl );
@@ -62,19 +61,12 @@ cntl_t* bli_cntl_create_node
 	bli_cntl_set_sub_prenode( NULL, cntl );
 	bli_cntl_set_sub_node( sub_node, cntl );
 
-	// Query the address of the node's packed mem_t entry so we can initialize
-	// key fields (to NULL or 0).
-	// NOTE: This initialization is important, since it allows threads to
-	// discern whether blocks have been acquired from the memory allocator.
-	pack_mem = bli_cntl_pack_mem( cntl );
-	bli_mem_clear( pack_mem );
-
 	return cntl;
 }
 
 void bli_cntl_free_node
      (
-       rntm_t* rntm,
+       pool_t* sba_pool,
        cntl_t* cntl
      )
 {
@@ -82,7 +74,7 @@ void bli_cntl_free_node
 	printf( "bli_cntl_free_node(): " );
 	#endif
 
-	bli_sba_release( rntm, cntl );
+	bli_sba_release( sba_pool, cntl );
 }
 
 void bli_cntl_clear_node
@@ -90,39 +82,20 @@ void bli_cntl_clear_node
        cntl_t* cntl
      )
 {
-	mem_t* pack_mem;
-
 	// Clear various fields in the control tree. Clearing these fields
 	// actually is not needed, but we do it for debugging/completeness.
 	bli_cntl_set_var_func( NULL, cntl );
 	bli_cntl_set_params( NULL, cntl );
 	bli_cntl_set_sub_prenode( NULL, cntl );
 	bli_cntl_set_sub_node( NULL, cntl );
-
-	// Clearing these fields is potentially more important if the control
-	// tree is cached somewhere and reused.
-	pack_mem = bli_cntl_pack_mem( cntl );
-	bli_mem_clear( pack_mem );
 }
 
 // -----------------------------------------------------------------------------
 
 void bli_cntl_free
      (
-       rntm_t*    rntm,
-       cntl_t*    cntl,
-       thrinfo_t* thread
-     )
-{
-	if ( thread != NULL ) bli_cntl_free_w_thrinfo( rntm, cntl, thread );
-	else                  bli_cntl_free_wo_thrinfo( rntm, cntl );
-}
-
-void bli_cntl_free_w_thrinfo
-     (
-       rntm_t*    rntm,
-       cntl_t*    cntl,
-       thrinfo_t* thread
+       pool_t* sba_pool,
+       cntl_t* cntl
      )
 {
 	// Base case: simply return when asked to free NULL nodes.
@@ -131,33 +104,13 @@ void bli_cntl_free_w_thrinfo
 	cntl_t* cntl_sub_prenode = bli_cntl_sub_prenode( cntl );
 	cntl_t* cntl_sub_node    = bli_cntl_sub_node( cntl );
 	void*   cntl_params      = bli_cntl_params( cntl );
-	mem_t*  cntl_pack_mem    = bli_cntl_pack_mem( cntl );
-
-	// Don't immediately dereference the prenode and subnode of the thrinfo_t
-	// node. In some cases, the thrinfo_t tree is not built out all the way,
-	// perhaps because there are more ways of parallelization than micropanels
-	// of data in this dimension, or because the problem is small enough that
-	// there is no gemm subproblem in bli_trsm_blk_var1(). Thus, we start with
-	// NULL values for these variables and only dereference the fields of the
-	// thrinfo_t struct if the thrinfo_t exists (ie: is non-NULL). We will also
-	// have to check the thrinfo_t pointer for NULLness before using it below,
-	// when checking if we need to free the pack_mem field of the cntl_t node
-	// (see below).
-	thrinfo_t* thread_sub_prenode = NULL;
-	thrinfo_t* thread_sub_node    = NULL;
-
-	if ( thread != NULL )
-	{
-		thread_sub_prenode = bli_thrinfo_sub_prenode( thread );
-		thread_sub_node    = bli_thrinfo_sub_node( thread );
-	}
 
 	// Only recurse into prenode branch if it exists.
 	if ( cntl_sub_prenode != NULL )
 	{
 		// Recursively free all memory associated with the sub-prenode and its
 		// children.
-		bli_cntl_free_w_thrinfo( rntm, cntl_sub_prenode, thread_sub_prenode );
+		bli_cntl_free( sba_pool, cntl_sub_prenode );
 	}
 
 	// Only recurse into the child node if it exists.
@@ -165,7 +118,7 @@ void bli_cntl_free_w_thrinfo
 	{
 		// Recursively free all memory associated with the sub-node and its
 		// children.
-		bli_cntl_free_w_thrinfo( rntm, cntl_sub_node, thread_sub_node );
+		bli_cntl_free( sba_pool, cntl_sub_node );
 	}
 
 	// Free the current node's params field, if it is non-NULL.
@@ -175,80 +128,19 @@ void bli_cntl_free_w_thrinfo
 		printf( "bli_cntl_free_w_thrinfo(): " );
 		#endif
 
-		bli_sba_release( rntm, cntl_params );
-	}
-
-	// Release the current node's pack mem_t entry back to the memory
-	// broker from which it originated, but only if the mem_t entry is
-	// allocated, and only if the current thread is chief for its group.
-	// Also note that we don't proceed with either of the above tests if
-	// the thrinfo_t pointer is NULL. (See above for background on when
-	// this can happen.)
-	if ( thread != NULL )
-	if ( bli_thread_am_ochief( thread ) )
-	if ( bli_mem_is_alloc( cntl_pack_mem ) )
-	{
-		#ifdef BLIS_ENABLE_MEM_TRACING
-		printf( "bli_cntl_free_w_thrinfo(): releasing mem pool block.\n" );
-		#endif
-
-		bli_pba_release( rntm, cntl_pack_mem );
+		bli_sba_release( sba_pool, cntl_params );
 	}
 
 	// Free the current node.
-	bli_cntl_free_node( rntm, cntl );
-}
-
-void bli_cntl_free_wo_thrinfo
-     (
-       rntm_t* rntm,
-       cntl_t* cntl
-     )
-{
-	// Base case: simply return when asked to free NULL nodes.
-	if ( cntl == NULL ) return;
-
-	cntl_t* cntl_sub_prenode = bli_cntl_sub_prenode( cntl );
-	cntl_t* cntl_sub_node    = bli_cntl_sub_node( cntl );
-	void*   cntl_params      = bli_cntl_params( cntl );
-	mem_t*  cntl_pack_mem    = bli_cntl_pack_mem( cntl );
-
-	{
-		// Recursively free all memory associated with the sub-prenode and its
-		// children.
-		bli_cntl_free_wo_thrinfo( rntm, cntl_sub_prenode );
-	}
-
-	{
-		// Recursively free all memory associated with the sub-node and its
-		// children.
-		bli_cntl_free_wo_thrinfo( rntm, cntl_sub_node );
-	}
-
-	// Free the current node's params field, if it is non-NULL.
-	if ( cntl_params != NULL )
-	{
-		bli_sba_release( rntm, cntl_params );
-	}
-
-	// Release the current node's pack mem_t entry back to the memory
-	// broker from which it originated, but only if the mem_t entry is
-	// allocated.
-	if ( bli_mem_is_alloc( cntl_pack_mem ) )
-	{
-		bli_pba_release( rntm, cntl_pack_mem );
-	}
-
-	// Free the current node.
-	bli_cntl_free_node( rntm, cntl );
+	bli_cntl_free_node( sba_pool, cntl );
 }
 
 // -----------------------------------------------------------------------------
 
 cntl_t* bli_cntl_copy
      (
-       rntm_t* rntm,
-       cntl_t* cntl
+             pool_t* sba_pool,
+       const cntl_t* cntl
      )
 {
 	// Make a copy of the current node. Notice that the source node
@@ -257,7 +149,7 @@ cntl_t* bli_cntl_copy
 	// field.
 	cntl_t* cntl_copy = bli_cntl_create_node
 	(
-      rntm,
+	  sba_pool,
 	  bli_cntl_family( cntl ),
 	  bli_cntl_bszid( cntl ),
 	  bli_cntl_var_func( cntl ),
@@ -273,7 +165,7 @@ cntl_t* bli_cntl_copy
 		// struct.
 		uint64_t params_size = bli_cntl_params_size( cntl );
 		void*    params_orig = bli_cntl_params( cntl );
-		void*    params_copy = bli_sba_acquire( rntm, ( size_t )params_size );
+		void*    params_copy = bli_sba_acquire( sba_pool, ( size_t )params_size );
 
 		// Copy the original params struct to the new memory region.
 		memcpy( params_copy, params_orig, params_size );
@@ -288,7 +180,7 @@ cntl_t* bli_cntl_copy
 	{
 		cntl_t* sub_prenode_copy = bli_cntl_copy
 		(
-		  rntm,
+		  sba_pool,
 		  bli_cntl_sub_prenode( cntl )
 		);
 
@@ -302,7 +194,7 @@ cntl_t* bli_cntl_copy
 	{
 		cntl_t* sub_node_copy = bli_cntl_copy
 		(
-		  rntm,
+		  sba_pool,
 		  bli_cntl_sub_node( cntl )
 		);
 
@@ -349,8 +241,8 @@ void bli_cntl_mark_family
 
 dim_t bli_cntl_calc_num_threads_in
      (
-       rntm_t* rntm,
-       cntl_t* cntl
+       const rntm_t* rntm,
+       const cntl_t* cntl
      )
 {
 	dim_t n_threads_in = 1;
