@@ -35,8 +35,8 @@
 
 #include "blis.h"
 
-// The array of cntx_t* pointers to cache modified contexts used by
-// induced methods.
+// The array of cntx_t* pointers to cache modified contexts used by induced
+// methods.
 static cntx_t** gks[ BLIS_NUM_ARCHS ];
 
 // The array of function pointers holding the registered context initialization
@@ -52,10 +52,25 @@ typedef void (*nat_cntx_init_ft)( cntx_t* cntx );
 typedef void (*ref_cntx_init_ft)( cntx_t* cntx );
 typedef void (*ind_cntx_init_ft)( ind_t method, cntx_t* cntx );
 
+// Cached copies of the pointers to the native and induced contexts for the
+// active subconfiguration. When BLIS_ENABLE_GKS_CACHING is enabled, these
+// pointers will be set once and then reused to fulfill subsequent context
+// queries.
+static cntx_t* cached_cntx_nat = NULL;
+static cntx_t* cached_cntx_ind = NULL;
+
+// A mutex to allow synchronous access to the gks when it needs to be updated
+// with a new entry corresponding to a context for an ind_t value.
+static bli_pthread_mutex_t gks_mutex = BLIS_PTHREAD_MUTEX_INITIALIZER;
+
 // -----------------------------------------------------------------------------
 
-void bli_gks_init( void )
+int bli_gks_init( void )
 {
+	// NOTE: This function is called once by ONLY ONE application thread per
+	// library init/finalize cycle (see bli_init.c). Thus, a mutex is not
+	// needed to protect the data initialization.
+
 	{
 		// Initialize the internal data structure we use to track registered
 		// contexts.
@@ -64,7 +79,8 @@ void bli_gks_init( void )
 		// Register a context for each architecture that was #define'd in
 		// bli_config.h.
 
-		// Intel architectures
+		// -- Intel architectures ----------------------------------------------
+
 #ifdef BLIS_CONFIG_SKX
 		bli_gks_register_cntx( BLIS_ARCH_SKX,         bli_cntx_init_skx,
 		                                              bli_cntx_init_skx_ref,
@@ -96,7 +112,8 @@ void bli_gks_init( void )
 		                                              bli_cntx_init_penryn_ind );
 #endif
 
-		// AMD architectures
+		// -- AMD architectures ------------------------------------------------
+
 #ifdef BLIS_CONFIG_ZEN3
 		bli_gks_register_cntx( BLIS_ARCH_ZEN3,        bli_cntx_init_zen3,
 		                                              bli_cntx_init_zen3_ref,
@@ -133,12 +150,38 @@ void bli_gks_init( void )
 		                                              bli_cntx_init_bulldozer_ind );
 #endif
 
-		// ARM architectures
+		// -- ARM architectures ------------------------------------------------
+
+		// -- ARM-SVE --
+#ifdef BLIS_CONFIG_ARMSVE
+		bli_gks_register_cntx( BLIS_ARCH_ARMSVE,      bli_cntx_init_armsve,
+		                                              bli_cntx_init_armsve_ref,
+		                                              bli_cntx_init_armsve_ind );
+#endif
 #ifdef BLIS_CONFIG_A64FX
-		bli_gks_register_cntx( BLIS_ARCH_A64FX,   bli_cntx_init_a64fx,
+		bli_gks_register_cntx( BLIS_ARCH_A64FX,       bli_cntx_init_a64fx,
 		                                              bli_cntx_init_a64fx_ref,
 		                                              bli_cntx_init_a64fx_ind );
 #endif
+
+		// -- ARM-NEON (4 pipes x 128-bit vectors) --
+#ifdef BLIS_CONFIG_ALTRAMAX
+		bli_gks_register_cntx( BLIS_ARCH_ALTRAMAX,    bli_cntx_init_altramax,
+		                                              bli_cntx_init_altramax_ref,
+		                                              bli_cntx_init_altramax_ind );
+#endif
+#ifdef BLIS_CONFIG_ALTRA
+		bli_gks_register_cntx( BLIS_ARCH_ALTRA,       bli_cntx_init_altra,
+		                                              bli_cntx_init_altra_ref,
+		                                              bli_cntx_init_altra_ind );
+#endif
+#ifdef BLIS_CONFIG_FIRESTORM
+		bli_gks_register_cntx( BLIS_ARCH_FIRESTORM,   bli_cntx_init_firestorm,
+		                                              bli_cntx_init_firestorm_ref,
+		                                              bli_cntx_init_firestorm_ind );
+#endif
+
+		// -- ARM (2 pipes x 128-bit vectors) --
 #ifdef BLIS_CONFIG_THUNDERX2
 		bli_gks_register_cntx( BLIS_ARCH_THUNDERX2,   bli_cntx_init_thunderx2,
 		                                              bli_cntx_init_thunderx2_ref,
@@ -154,21 +197,8 @@ void bli_gks_init( void )
 		                                              bli_cntx_init_cortexa53_ref,
 		                                              bli_cntx_init_cortexa53_ind );
 #endif
-#ifdef BLIS_CONFIG_ARMSVE
-		bli_gks_register_cntx( BLIS_ARCH_ARMSVE,      bli_cntx_init_armsve,
-		                                              bli_cntx_init_armsve_ref,
-		                                              bli_cntx_init_armsve_ind );
-#endif
-#ifdef BLIS_CONFIG_A64FX
-		bli_gks_register_cntx( BLIS_ARCH_A64FX,       bli_cntx_init_a64fx,
-		                                              bli_cntx_init_a64fx_ref,
-		                                              bli_cntx_init_a64fx_ind );
-#endif
-#ifdef BLIS_CONFIG_FIRESTORM
-		bli_gks_register_cntx( BLIS_ARCH_FIRESTORM,   bli_cntx_init_firestorm,
-		                                              bli_cntx_init_firestorm_ref,
-		                                              bli_cntx_init_firestorm_ind );
-#endif
+
+		// -- ARM (older 32-bit microarchitectures) --
 #ifdef BLIS_CONFIG_CORTEXA15
 		bli_gks_register_cntx( BLIS_ARCH_CORTEXA15,   bli_cntx_init_cortexa15,
 		                                              bli_cntx_init_cortexa15_ref,
@@ -180,12 +210,13 @@ void bli_gks_init( void )
 		                                              bli_cntx_init_cortexa9_ind );
 #endif
 
-		// IBM architectures
+		// -- IBM architectures ------------------------------------------------
+
 #ifdef BLIS_CONFIG_POWER10
 		bli_gks_register_cntx( BLIS_ARCH_POWER10,     bli_cntx_init_power10,
 		                                              bli_cntx_init_power10_ref,
 		                                              bli_cntx_init_power10_ind );
-#endif													  
+#endif
 #ifdef BLIS_CONFIG_POWER9
 		bli_gks_register_cntx( BLIS_ARCH_POWER9,      bli_cntx_init_power9,
 		                                              bli_cntx_init_power9_ref,
@@ -202,18 +233,67 @@ void bli_gks_init( void )
 		                                              bli_cntx_init_bgq_ind );
 #endif
 
-		// Generic architectures
+		// -- RISC-V architectures --------------------------------------------
+
+#ifdef BLIS_CONFIG_RV32I
+		bli_gks_register_cntx( BLIS_ARCH_RV32I,       bli_cntx_init_rv32i,
+		                                              bli_cntx_init_rv32i_ref,
+		                                              bli_cntx_init_rv32i_ind );
+#endif
+
+#ifdef BLIS_CONFIG_RV64I
+		bli_gks_register_cntx( BLIS_ARCH_RV64I,       bli_cntx_init_rv64i,
+		                                              bli_cntx_init_rv64i_ref,
+		                                              bli_cntx_init_rv64i_ind );
+#endif
+
+#ifdef BLIS_CONFIG_RV32IV
+		bli_gks_register_cntx( BLIS_ARCH_RV32IV,      bli_cntx_init_rv32iv,
+		                                              bli_cntx_init_rv32iv_ref,
+		                                              bli_cntx_init_rv32iv_ind );
+#endif
+
+#ifdef BLIS_CONFIG_RV64IV
+		bli_gks_register_cntx( BLIS_ARCH_RV64IV,      bli_cntx_init_rv64iv,
+		                                              bli_cntx_init_rv64iv_ref,
+		                                              bli_cntx_init_rv64iv_ind );
+#endif
+
+		// -- SiFive architectures ----------------------------------------------
+
+#ifdef BLIS_CONFIG_SIFIVE_X280
+		bli_gks_register_cntx( BLIS_ARCH_SIFIVE_X280, bli_cntx_init_sifive_x280,
+		                                              bli_cntx_init_sifive_x280_ref,
+		                                              bli_cntx_init_sifive_x280_ind );
+#endif
+
+		// -- Generic architectures --------------------------------------------
+
 #ifdef BLIS_CONFIG_GENERIC
 		bli_gks_register_cntx( BLIS_ARCH_GENERIC,     bli_cntx_init_generic,
 		                                              bli_cntx_init_generic_ref,
 		                                              bli_cntx_init_generic_ind );
 #endif
 	}
+
+#ifdef BLIS_ENABLE_GKS_CACHING
+	// Deep-query and cache the native and induced method contexts so they are
+	// ready to go when needed (by BLIS or the application). Notice that we use
+	// the _noinit() APIs, which skip their internal calls to bli_init_once().
+	// The reasons: (1) Skipping that call is necessary to prevent an infinite
+	// loop since the current function, bli_gks_init(), is called from within
+	// bli_init_once(); and (2) we can guarantee that the gks has been
+	// initialized given that bli_gks_init() is about to return.
+	cached_cntx_nat = ( cntx_t* )bli_gks_query_nat_cntx_noinit();
+	cached_cntx_ind = ( cntx_t* )bli_gks_query_ind_cntx_noinit( BLIS_1M );
+#endif
+
+	return 0;
 }
 
 // -----------------------------------------------------------------------------
 
-void bli_gks_finalize( void )
+int bli_gks_finalize( void )
 {
 	arch_t id;
 	ind_t  ind;
@@ -226,7 +306,7 @@ void bli_gks_finalize( void )
 		// Iterate over the architectures in the gks array.
 		for ( id = 0; id < BLIS_NUM_ARCHS; ++id )
 		{
-			cntx_t** restrict gks_id = gks[ id ];
+			cntx_t** gks_id = gks[ id ];
 
 			// Only consider context arrays for architectures that were allocated
 			// in the first place.
@@ -236,7 +316,7 @@ void bli_gks_finalize( void )
 				// referenced by cntx_pp.
 				for ( ind = 0; ind < BLIS_NUM_IND_METHODS; ++ind )
 				{
-					cntx_t* restrict gks_id_ind = gks_id[ ind ];
+					cntx_t* gks_id_ind = gks_id[ ind ];
 
 					// If the current context was allocated, free it.
 					if ( gks_id_ind != NULL )
@@ -260,6 +340,14 @@ void bli_gks_finalize( void )
 
 	}
 	// END CRITICAL SECTION
+
+#ifdef BLIS_ENABLE_GKS_CACHING
+	// Clear the cached pointers to the native and induced contexts.
+	cached_cntx_nat = NULL;
+	cached_cntx_ind = NULL;
+#endif
+
+	return 0;
 }
 
 // -----------------------------------------------------------------------------
@@ -267,7 +355,7 @@ void bli_gks_finalize( void )
 void bli_gks_init_index( void )
 {
 	// This function is called by bli_gks_init(). It simply initializes all
-	// architecture id elements of the internal arrays to NULL. 
+	// architecture id elements of the internal arrays to NULL.
 
 	const size_t gks_size = sizeof( cntx_t* ) * BLIS_NUM_ARCHS;
 	const size_t fpa_size = sizeof( void_fp ) * BLIS_NUM_ARCHS;
@@ -282,7 +370,7 @@ void bli_gks_init_index( void )
 
 // -----------------------------------------------------------------------------
 
-cntx_t* bli_gks_lookup_nat_cntx
+const cntx_t* bli_gks_lookup_nat_cntx
      (
        arch_t id
      )
@@ -295,7 +383,7 @@ cntx_t* bli_gks_lookup_nat_cntx
 
 // -----------------------------------------------------------------------------
 
-cntx_t* bli_gks_lookup_ind_cntx
+const cntx_t* bli_gks_lookup_ind_cntx
      (
        arch_t id,
        ind_t  ind
@@ -316,8 +404,8 @@ cntx_t* bli_gks_lookup_ind_cntx
 
 	// Index into the array of context pointers for the given architecture id,
 	// and then index into the subarray for the given induced method.
-	cntx_t** restrict gks_id     = gks[ id ];
-	cntx_t*  restrict gks_id_ind = gks_id[ ind ];
+	cntx_t** gks_id     = gks[ id ];
+	cntx_t*  gks_id_ind = gks_id[ ind ];
 
 	// Return the context pointer at gks_id_ind.
 	return gks_id_ind;
@@ -325,7 +413,7 @@ cntx_t* bli_gks_lookup_ind_cntx
 
 // -----------------------------------------------------------------------------
 
-cntx_t** bli_gks_lookup_id
+const cntx_t* const * bli_gks_lookup_id
      (
        arch_t id
      )
@@ -336,10 +424,10 @@ cntx_t** bli_gks_lookup_id
 	// initialized.
 
 	// Index into the array of context pointers for the given architecture id.
-	cntx_t** restrict gks_id = gks[ id ];
+	cntx_t** gks_id = gks[ id ];
 
 	// Return the context pointer at gks_id_ind.
-	return gks_id;
+	return ( const cntx_t* const * )gks_id;
 }
 
 // -----------------------------------------------------------------------------
@@ -382,7 +470,7 @@ void bli_gks_register_cntx
 	// functions for reference kernels and induced method execution. The
 	// former will be used whenever we need to obtain reference kernels and
 	// latter will be used later on if the user calls a level-3 function
-	// with induced execution enabled. 
+	// with induced execution enabled.
 	cntx_ref_init[ id ] = ref_fp;
 	cntx_ind_init[ id ] = ind_fp;
 
@@ -405,7 +493,7 @@ void bli_gks_register_cntx
 	gks[ id ] = bli_calloc_intl( sizeof( cntx_t* ) * BLIS_NUM_IND_METHODS, &r_val );
 
 	// Alias the allocated array for readability.
-	cntx_t** restrict gks_id = gks[ id ];
+	cntx_t** gks_id = gks[ id ];
 
 	#ifdef BLIS_ENABLE_MEM_TRACING
 	printf( "bli_gks_register_cntx(): " );
@@ -417,7 +505,7 @@ void bli_gks_register_cntx
 	gks_id[ BLIS_NAT ] = bli_calloc_intl( sizeof( cntx_t ), &r_val );
 
 	// Alias the allocated context address for readability.
-	cntx_t* restrict gks_id_nat = gks_id[ BLIS_NAT ];
+	cntx_t* gks_id_nat = gks_id[ BLIS_NAT ];
 
 	// Call the context initialization function on the element of the newly
 	// allocated array corresponding to native execution.
@@ -440,12 +528,12 @@ void bli_gks_register_cntx
 	// kernel is called.
 	err_t e_val;
 
-	blksz_t* restrict mc = bli_cntx_get_blksz( BLIS_MC, gks_id_nat );
-	blksz_t* restrict nc = bli_cntx_get_blksz( BLIS_NC, gks_id_nat );
-	blksz_t* restrict kc = bli_cntx_get_blksz( BLIS_KC, gks_id_nat );
-	blksz_t* restrict mr = bli_cntx_get_blksz( BLIS_MR, gks_id_nat );
-	blksz_t* restrict nr = bli_cntx_get_blksz( BLIS_NR, gks_id_nat );
-	blksz_t* restrict kr = bli_cntx_get_blksz( BLIS_KR, gks_id_nat );
+	const blksz_t* mc = bli_cntx_get_blksz( BLIS_MC, gks_id_nat );
+	const blksz_t* nc = bli_cntx_get_blksz( BLIS_NC, gks_id_nat );
+	const blksz_t* kc = bli_cntx_get_blksz( BLIS_KC, gks_id_nat );
+	const blksz_t* mr = bli_cntx_get_blksz( BLIS_MR, gks_id_nat );
+	const blksz_t* nr = bli_cntx_get_blksz( BLIS_NR, gks_id_nat );
+	const blksz_t* kr = bli_cntx_get_blksz( BLIS_KR, gks_id_nat );
 
 	e_val = bli_check_valid_mc_mod_mult( mc, mr ); bli_check_error_code( e_val );
 	e_val = bli_check_valid_nc_mod_mult( nc, nr ); bli_check_error_code( e_val );
@@ -463,15 +551,43 @@ void bli_gks_register_cntx
 
 // -----------------------------------------------------------------------------
 
-cntx_t* bli_gks_query_cntx( void )
+const cntx_t* bli_gks_query_cntx( void )
 {
 	return bli_gks_query_nat_cntx();
 }
 
-cntx_t* bli_gks_query_nat_cntx( void )
+// -----------------------------------------------------------------------------
+
+const cntx_t* bli_gks_query_nat_cntx( void )
 {
 	bli_init_once();
 
+#ifdef BLIS_ENABLE_GKS_CACHING
+
+	// Return a pointer to the context for native execution that was deep-
+	// queried and cached at the end of bli_gks_init().
+	return cached_cntx_nat;
+
+#else
+
+	// Deep-query and return the address of a context for native execution.
+	return bli_gks_query_nat_cntx_impl();
+
+#endif
+}
+
+const cntx_t* bli_gks_query_nat_cntx_noinit( void )
+{
+	// NOTE: This function purposefully avoids calling bli_init_once() so that
+	// it is safe to call during inititalization.
+
+	return bli_gks_query_nat_cntx_impl();
+}
+
+// -----------------------------------------------------------------------------
+
+const cntx_t* bli_gks_query_nat_cntx_impl( void )
+{
 	// Return the address of the native context for the architecture id
 	// corresponding to the current hardware, as determined by
 	// bli_arch_query_id().
@@ -480,44 +596,62 @@ cntx_t* bli_gks_query_nat_cntx( void )
 	arch_t id = bli_arch_query_id();
 
 	// Use the architecture id to look up a pointer to its context.
-	cntx_t* cntx = bli_gks_lookup_nat_cntx( id );
+	const cntx_t* cntx = bli_gks_lookup_nat_cntx( id );
 
 	return cntx;
 }
 
 // -----------------------------------------------------------------------------
 
-cntx_t* bli_gks_query_cntx_noinit( void )
-{
-	// This function is identical to bli_gks_query_cntx(), except that it
-	// does not call bli_init_once().
-
-	// Query the architecture id.
-	arch_t id = bli_arch_query_id();
-
-	// Use the architecture id to look up a pointer to its context.
-	cntx_t* cntx = bli_gks_lookup_nat_cntx( id );
-
-	return cntx;
-}
-
-// -----------------------------------------------------------------------------
-
-// A mutex to allow synchronous access to the gks when it needs to be updated
-// with a new entry corresponding to a context for an ind_t value.
-static bli_pthread_mutex_t gks_mutex = BLIS_PTHREAD_MUTEX_INITIALIZER;
-
-cntx_t* bli_gks_query_ind_cntx
+const cntx_t* bli_gks_query_ind_cntx
      (
-       ind_t ind,
-       num_t dt
+       ind_t ind
      )
 {
 	bli_init_once();
 
+#ifdef BLIS_ENABLE_GKS_CACHING
+
+	// If for some reason the native context was requested, we return its
+	// address instead of the one for induced execution.
+	if ( ind == BLIS_NAT ) return cached_cntx_nat;
+
+	// Return a pointer to the context for the induced method that was deep-
+	// queried and cached at the end of bli_gks_init().
+	return cached_cntx_ind;
+
+#else
+
+	// Deep-query and return the address of a context for the requested induced
+	// method. (In this case, caching never takes place since it was disabled
+	// at configure-time.)
+	return bli_gks_query_ind_cntx_impl( ind );
+
+#endif
+}
+
+const cntx_t* bli_gks_query_ind_cntx_noinit
+     (
+       ind_t ind
+     )
+{
+	// NOTE: This function purposefully avoids calling bli_init_once() so that
+	// it is safe to call during inititalization.
+
+	return bli_gks_query_ind_cntx_impl( ind );
+}
+
+// -----------------------------------------------------------------------------
+
+const cntx_t* bli_gks_query_ind_cntx_impl
+     (
+       ind_t ind
+     )
+{
 	cntx_t* gks_id_ind;
 	err_t r_val;
 
+
 	// Return the address of a context that will be suited for executing a
 	// level-3 operation via the requested induced method (and datatype) for
 	// the architecture id corresponding to the current hardware, as
@@ -526,10 +660,13 @@ cntx_t* bli_gks_query_ind_cntx
 	// This function is called when a level-3 operation via induced method is
 	// called, e.g. bli_gemm1m(). If this is the first time that induced method
 	// is being executed since bli_gks_init(), the necessary context structure
-	// is allocated and initialized. If this is not the first time, then the
-	// address of a previously-allocated and initialized (cached) context is
-	// returned. Note that much of this must be done with mutual exclusion to
-	// ensure thread safety and deterministic behavior.
+	// is allocated. If this is not the first time a context for the requested
+	// induced method was queried, then the memory will already be allocated
+	// and initialized, and the previous cntx_t struct will be overwritten.
+	// The function will then return the address to the newly-initialized (or
+	// previously-allocated-but-reinitialized) cntx_t struct. Note that some of
+	// this function must be executed with mutual exclusion to ensure thread
+	// safety and deterministic behavior.
 
 	// Query the architecture id.
 	arch_t id = bli_arch_query_id();
@@ -547,8 +684,8 @@ cntx_t* bli_gks_query_ind_cntx
 
 	// Query the gks for the array of context pointers corresponding to the
 	// given architecture id.
-	cntx_t** restrict gks_id     = gks[ id ];
-	cntx_t*  restrict gks_id_nat = gks_id[ BLIS_NAT ];
+	cntx_t** gks_id     = gks[ id ];
+	cntx_t*  gks_id_nat = gks_id[ BLIS_NAT ];
 
 	// If for some reason the native context was requested, we can return
 	// its address early.
@@ -577,23 +714,24 @@ cntx_t* bli_gks_query_ind_cntx
 			// gks_id[ ind ].
 			gks_id_ind    = bli_calloc_intl( sizeof( cntx_t ), &r_val );
 			gks_id[ ind ] = gks_id_ind;
-
-			// Before we can call the induced method context initialization
-			// function on the newly allocated structure, we must first copy
-			// over the contents of the native context.
-			*gks_id_ind = *gks_id_nat;
-			
-			// Use the architecture id to look up the function pointer to the
-			// context initialization function for induced methods.
-			ind_cntx_init_ft f = cntx_ind_init[ id ];
-
-			// Now we modify the context (so that it contains the proper values
-			// for its induced method) by calling the context initialization
-			// function for the current induced method. (That function assumes
-			// that the context is pre- initialized with values for native
-			// execution.)
-			f( ind, gks_id_ind );
 		}
+
+		// Before we can call the induced method context initialization
+		// function on the newly allocated structure, we must first copy
+		// over the contents of the native context. If a previous context
+		// was already copied, this will overwrite those previous values.
+		*gks_id_ind = *gks_id_nat;
+
+		// Use the architecture id to look up the function pointer to the
+		// context initialization function for induced methods.
+		ind_cntx_init_ft f = cntx_ind_init[ id ];
+
+		// Now we modify the context (so that it contains the proper values
+		// for its induced method) by calling the context initialization
+		// function for the current induced method. (That function assumes
+		// that the context is pre-initialized with values for native
+		// execution.)
+		f( ind, gks_id_ind );
 	}
 	// END CRITICAL SECTION
 
@@ -634,9 +772,9 @@ void bli_gks_init_ref_cntx
 
 bool bli_gks_cntx_l3_nat_ukr_is_ref
      (
-       num_t   dt,
-       l3ukr_t ukr_id,
-       cntx_t* cntx
+             num_t   dt,
+             ukr_t   ukr_id,
+       const cntx_t* cntx
      )
 {
 	cntx_t ref_cntx;
@@ -647,8 +785,8 @@ bool bli_gks_cntx_l3_nat_ukr_is_ref
 
 	// Query each context for the micro-kernel function pointer for the
 	// specified datatype.
-	void_fp ref_fp = bli_cntx_get_l3_nat_ukr_dt( dt, ukr_id, &ref_cntx );
-	void_fp fp     = bli_cntx_get_l3_nat_ukr_dt( dt, ukr_id, cntx );
+	void_fp ref_fp = bli_cntx_get_ukr_dt( dt, ukr_id, &ref_cntx );
+	void_fp fp     = bli_cntx_get_ukr_dt( dt, ukr_id, cntx );
 
 	// Return the result.
 	return fp == ref_fp;
@@ -658,7 +796,7 @@ bool bli_gks_cntx_l3_nat_ukr_is_ref
 // -- level-3 micro-kernel implementation strings ------------------------------
 //
 
-static char* bli_gks_l3_ukr_impl_str[BLIS_NUM_UKR_IMPL_TYPES] =
+static const char* bli_gks_l3_ukr_impl_str[BLIS_NUM_UKR_IMPL_TYPES] =
 {
 	"refrnce",
 	"virtual",
@@ -668,15 +806,15 @@ static char* bli_gks_l3_ukr_impl_str[BLIS_NUM_UKR_IMPL_TYPES] =
 
 // -----------------------------------------------------------------------------
 
-char* bli_gks_l3_ukr_impl_string( l3ukr_t ukr, ind_t method, num_t dt )
+const char* bli_gks_l3_ukr_impl_string( ukr_t ukr, ind_t method, num_t dt )
 {
 	kimpl_t ki;
 
 	// Query the context for the current induced method and datatype, and
 	// then query the ukernel function pointer for the given datatype from
 	// that context.
-	cntx_t* cntx  = bli_gks_query_ind_cntx( method, dt );
-	void_fp fp    = bli_cntx_get_l3_vir_ukr_dt( dt, ukr, cntx );
+	const cntx_t* cntx = bli_gks_query_ind_cntx( method );
+	void_fp fp         = bli_cntx_get_ukr_dt( dt, ukr, cntx );
 
 	// Check whether the ukernel function pointer is NULL for the given
 	// datatype. If it is NULL, return the string for not applicable.
@@ -691,7 +829,7 @@ char* bli_gks_l3_ukr_impl_string( l3ukr_t ukr, ind_t method, num_t dt )
 }
 
 #if 0
-char* bli_gks_l3_ukr_avail_impl_string( l3ukr_t ukr, num_t dt )
+char* bli_gks_l3_ukr_avail_impl_string( ukr_t ukr, num_t dt )
 {
 	opid_t  oper;
 	ind_t   method;
@@ -716,7 +854,7 @@ char* bli_gks_l3_ukr_avail_impl_string( l3ukr_t ukr, num_t dt )
 }
 #endif
 
-kimpl_t bli_gks_l3_ukr_impl_type( l3ukr_t ukr, ind_t method, num_t dt )
+kimpl_t bli_gks_l3_ukr_impl_type( ukr_t ukr, ind_t method, num_t dt )
 {
 	// If the current available induced method is not native, it
 	// must be virtual.
@@ -731,8 +869,6 @@ kimpl_t bli_gks_l3_ukr_impl_type( l3ukr_t ukr, ind_t method, num_t dt )
 		// method to the typed function pointer within the known
 		// reference ukrs object.
 
-		cntx_t ref_cntx_l;
-
 		// Query the architecture id.
 		arch_t id = bli_arch_query_id();
 
@@ -743,23 +879,13 @@ kimpl_t bli_gks_l3_ukr_impl_type( l3ukr_t ukr, ind_t method, num_t dt )
 			bli_check_error_code( e_val );
 		}
 
-		// Obtain the function pointer to the context initialization function
-		// for reference kernels.
-		ref_cntx_init_ft f = cntx_ref_init[ id ];
-
-		// Initialize a local context with reference kernels and related values.
-		f( &ref_cntx_l );
-
 		// Query the native context from the gks.
-		cntx_t* nat_cntx = bli_gks_lookup_nat_cntx( id );
+		const cntx_t* nat_cntx = bli_gks_lookup_nat_cntx( id );
 
-		// Query the native ukernel func_t from both the native and reference
-		// contexts.
-		void_fp nat_fp = bli_cntx_get_l3_nat_ukr_dt( dt, ukr, nat_cntx );
-		void_fp ref_fp = bli_cntx_get_l3_nat_ukr_dt( dt, ukr, &ref_cntx_l );
-
-		if ( nat_fp == ref_fp ) return BLIS_REFERENCE_UKERNEL;
-		else                    return BLIS_OPTIMIZED_UKERNEL;
+		if ( bli_gks_cntx_l3_nat_ukr_is_ref( dt, ukr, nat_cntx ) )
+			return BLIS_REFERENCE_UKERNEL;
+		else
+			return BLIS_OPTIMIZED_UKERNEL;
 	}
 }
 
