@@ -41,15 +41,13 @@ void bli_obj_scalar_init_detached
        obj_t* beta
      )
 {
-	void* p;
-
 	// Initialize beta without a buffer and then attach its internal buffer.
 	// NOTE: This initializes both the storage datatype and scalar datatype
 	// bitfields within beta to dt.
 	bli_obj_create_without_buffer( dt, 1, 1, beta );
 
 	// Query the address of the object's internal scalar buffer.
-	p = bli_obj_internal_scalar_buffer( beta );
+	void* p = bli_obj_internal_scalar_buffer( beta );
 
 	// Update the object.
 	bli_obj_set_buffer( p, beta );
@@ -59,10 +57,10 @@ void bli_obj_scalar_init_detached
 
 void bli_obj_scalar_init_detached_copy_of
      (
-       num_t  dt,
-       conj_t conj,
-       obj_t* alpha,
-       obj_t* beta
+             num_t  dt,
+             conj_t conj,
+       const obj_t* alpha,
+             obj_t* beta
      )
 {
 	obj_t alpha_local;
@@ -81,8 +79,8 @@ void bli_obj_scalar_init_detached_copy_of
 
 void bli_obj_scalar_detach
      (
-       obj_t* a,
-       obj_t* alpha
+       const obj_t* a,
+             obj_t* alpha
      )
 {
 	// Use the scalar datatype of A as the storage datatype of the detached
@@ -103,9 +101,9 @@ void bli_obj_scalar_detach
 
 void bli_obj_scalar_attach
      (
-       conj_t conj,
-       obj_t* alpha,
-       obj_t* a
+             conj_t conj,
+       const obj_t* alpha,
+             obj_t* a
      )
 {
 	obj_t alpha_cast;
@@ -165,8 +163,8 @@ void bli_obj_scalar_cast_to
 
 void bli_obj_scalar_apply_scalar
      (
-       obj_t* alpha,
-       obj_t* a
+       const obj_t* alpha,
+             obj_t* a
      )
 {
 	obj_t alpha_cast;
@@ -193,9 +191,9 @@ void bli_obj_scalar_reset
        obj_t* a
      )
 {
-	num_t dt       = bli_obj_scalar_dt( a );
-	void* scalar_a = bli_obj_internal_scalar_buffer( a );
-	void* one      = bli_obj_buffer_for_const( dt, &BLIS_ONE );
+	num_t       dt       = bli_obj_scalar_dt( a );
+	void*       scalar_a = bli_obj_internal_scalar_buffer( a );
+	const void* one      = bli_obj_buffer_for_const( dt, &BLIS_ONE );
 
 	if      ( bli_is_float( dt )    ) *(( float*    )scalar_a) = *(( float*    )one);
 	else if ( bli_is_double( dt )   ) *(( double*   )scalar_a) = *(( double*   )one);
@@ -211,9 +209,9 @@ bool bli_obj_scalar_has_nonzero_imag
        obj_t* a
      )
 {
-	bool   r_val     = FALSE;
-	num_t  dt        = bli_obj_scalar_dt( a );
-	void*  scalar_a  = bli_obj_internal_scalar_buffer( a );
+	bool  r_val    = FALSE;
+	num_t dt       = bli_obj_scalar_dt( a );
+	void* scalar_a = bli_obj_internal_scalar_buffer( a );
 
 	// FGVZ: Reimplement by using bli_obj_imag_part() and then
 	// bli_obj_equals( &BLIS_ZERO, ... ).
@@ -236,16 +234,15 @@ bool bli_obj_scalar_has_nonzero_imag
 
 bool bli_obj_scalar_equals
      (
-       obj_t* a,
-       obj_t* beta
+       const obj_t* a,
+       const obj_t* beta
      )
 {
 	obj_t scalar_a;
-	bool  r_val;
 
 	bli_obj_scalar_detach( a, &scalar_a );
 
-	r_val = bli_obj_equals( &scalar_a, beta );
+	bool r_val = bli_obj_equals( &scalar_a, beta );
 
 	return r_val;
 }
