@@ -34,8 +34,9 @@
 
 #include "blis.h"
 
-bool bli_obj_equals( obj_t* a, obj_t* b )
+bool bli_obj_equals( const obj_t* a, const obj_t* b )
 {
+#if 0
 	bool  r_val = FALSE;
 	num_t dt_a;
 	num_t dt_b;
@@ -80,9 +81,21 @@ bool bli_obj_equals( obj_t* a, obj_t* b )
 	}
 
 	return r_val;
+#else
+	bool r_val;
+
+	if ( bli_obj_is_1x1( a ) && bli_obj_is_1x1( b ) )
+		bli_eqsc( a, b, &r_val );
+	else if ( bli_obj_is_vector( a ) && bli_obj_is_vector( b ) )
+		bli_eqv( a, b, &r_val );
+	else
+		bli_eqm( a, b, &r_val );
+
+	return r_val;
+#endif
 }
 
-bool bli_obj_imag_equals( obj_t* a, obj_t* b )
+bool bli_obj_imag_equals( const obj_t* a, const obj_t* b )
 {
 #if 0
 	bool  r_val = FALSE;
@@ -152,7 +165,7 @@ bool bli_obj_imag_equals( obj_t* a, obj_t* b )
 	return r_val;
 }
 
-bool bli_obj_imag_is_zero( obj_t* a )
+bool bli_obj_imag_is_zero( const obj_t* a )
 {
 	bool r_val = TRUE;
 
