@@ -34,13 +34,13 @@
 
 BLIS_EXPORT_BLIS void bli_projv
      (
-       obj_t* x,
-       obj_t* y
+       const obj_t* x,
+       const obj_t* y
      );
 
 void bli_projv_check
      (
-       obj_t* x,
-       obj_t* y
+       const obj_t* x,
+       const obj_t* y
      );
 
