@@ -35,16 +35,17 @@
 #ifndef BLIS_EXTERN_DEFS_H
 #define BLIS_EXTERN_DEFS_H
 
-BLIS_EXPORT_BLIS extern obj_t BLIS_TWO;
-BLIS_EXPORT_BLIS extern obj_t BLIS_ONE;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_TWO;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_ONE;
 //BLIS_EXPORT_BLIS extern obj_t BLIS_ONE_HALF;
-BLIS_EXPORT_BLIS extern obj_t BLIS_ZERO;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_ZERO;
 //BLIS_EXPORT_BLIS extern obj_t BLIS_MINUS_ONE_HALF;
-BLIS_EXPORT_BLIS extern obj_t BLIS_MINUS_ONE;
-BLIS_EXPORT_BLIS extern obj_t BLIS_MINUS_TWO;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_MINUS_ONE;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_MINUS_TWO;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_ONE_I;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_MINUS_ONE_I;
+BLIS_EXPORT_BLIS extern const obj_t BLIS_NAN;
 
 BLIS_EXPORT_BLIS extern thrcomm_t BLIS_SINGLE_COMM;
-BLIS_EXPORT_BLIS extern thrinfo_t BLIS_PACKM_SINGLE_THREADED;
-BLIS_EXPORT_BLIS extern thrinfo_t BLIS_GEMM_SINGLE_THREADED;
 
 #endif
