@@ -42,13 +42,13 @@
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       dim_t    n, \
-       ctype*   x, inc_t incx, \
-       ctype_r* asum  \
+             dim_t    n, \
+       const ctype*   x, inc_t incx, \
+             ctype_r* asum  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROTR_BASIC0( asumv )
+INSERT_GENTPROTR_BASIC( asumv )
 
 
 #undef  GENTPROT
@@ -56,15 +56,15 @@ INSERT_GENTPROTR_BASIC0( asumv )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       uplo_t  uploa, \
-       dim_t   m, \
-       ctype*  a, inc_t rs_a, inc_t cs_a  \
+       uplo_t uploa, \
+       dim_t  m, \
+       ctype* a, inc_t rs_a, inc_t cs_a  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( mkherm )
-INSERT_GENTPROT_BASIC0( mksymm )
-INSERT_GENTPROT_BASIC0( mktrim )
+INSERT_GENTPROT_BASIC( mkherm )
+INSERT_GENTPROT_BASIC( mksymm )
+INSERT_GENTPROT_BASIC( mktrim )
 
 
 #undef  GENTPROTR
@@ -72,15 +72,15 @@ INSERT_GENTPROT_BASIC0( mktrim )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       dim_t    n, \
-       ctype*   x, inc_t incx, \
-       ctype_r* norm  \
+             dim_t    n, \
+       const ctype*   x, inc_t incx, \
+             ctype_r* norm  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROTR_BASIC0( norm1v )
-INSERT_GENTPROTR_BASIC0( normfv )
-INSERT_GENTPROTR_BASIC0( normiv )
+INSERT_GENTPROTR_BASIC( norm1v )
+INSERT_GENTPROTR_BASIC( normfv )
+INSERT_GENTPROTR_BASIC( normiv )
 
 
 #undef  GENTPROTR
@@ -88,19 +88,19 @@ INSERT_GENTPROTR_BASIC0( normiv )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       doff_t   diagoffx, \
-       diag_t   diagx, \
-       uplo_t   uplox, \
-       dim_t    m, \
-       dim_t    n, \
-       ctype*   x, inc_t rs_x, inc_t cs_x, \
-       ctype_r* norm  \
+             doff_t   diagoffx, \
+             diag_t   diagx, \
+             uplo_t   uplox, \
+             dim_t    m, \
+             dim_t    n, \
+       const ctype*   x, inc_t rs_x, inc_t cs_x, \
+             ctype_r* norm  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROTR_BASIC0( norm1m )
-INSERT_GENTPROTR_BASIC0( normfm )
-INSERT_GENTPROTR_BASIC0( normim )
+INSERT_GENTPROTR_BASIC( norm1m )
+INSERT_GENTPROTR_BASIC( normfm )
+INSERT_GENTPROTR_BASIC( normim )
 
 
 #undef  GENTPROT
@@ -108,14 +108,13 @@ INSERT_GENTPROTR_BASIC0( normim )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       char*  s1, \
        dim_t  n, \
-       void*  x, inc_t incx, \
-       char*  format, \
-       char*  s2  \
+       ctype* x, inc_t incx  \
+       BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0_I( printv )
+INSERT_GENTPROT_BASIC( randv )
+INSERT_GENTPROT_BASIC( randnv )
 
 
 #undef  GENTPROT
@@ -123,46 +122,16 @@ INSERT_GENTPROT_BASIC0_I( printv )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       char*  s1, \
+       doff_t diagoffx, \
+       uplo_t uplox, \
        dim_t  m, \
        dim_t  n, \
-       void*  x, inc_t rs_x, inc_t cs_x, \
-       char*  format, \
-       char*  s2  \
-     );
-
-INSERT_GENTPROT_BASIC0_I( printm )
-
-
-#undef  GENTPROT
-#define GENTPROT( ctype, ch, opname ) \
-\
-BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
-     ( \
-       dim_t    n, \
-       ctype*   x, inc_t incx  \
+       ctype* x, inc_t rs_x, inc_t cs_x  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROT_BASIC0( randv )
-INSERT_GENTPROT_BASIC0( randnv )
-
-
-#undef  GENTPROT
-#define GENTPROT( ctype, ch, opname ) \
-\
-BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
-     ( \
-       doff_t  diagoffx, \
-       uplo_t  uplox, \
-       dim_t   m, \
-       dim_t   n, \
-       ctype*  x, inc_t rs_x, inc_t cs_x  \
-       BLIS_TAPI_EX_PARAMS  \
-     );
-
-INSERT_GENTPROT_BASIC0( randm )
-INSERT_GENTPROT_BASIC0( randnm )
+INSERT_GENTPROT_BASIC( randm )
+INSERT_GENTPROT_BASIC( randnm )
 
 
 #undef  GENTPROTR
@@ -170,13 +139,114 @@ INSERT_GENTPROT_BASIC0( randnm )
 \
 BLIS_EXPORT_BLIS void PASTEMAC2(ch,opname,EX_SUF) \
      ( \
-       dim_t    n, \
-       ctype*   x, inc_t incx, \
-       ctype_r* scale, \
-       ctype_r* sumsq  \
+             dim_t    n, \
+       const ctype*   x, inc_t incx, \
+             ctype_r* scale, \
+             ctype_r* sumsq  \
        BLIS_TAPI_EX_PARAMS  \
      );
 
-INSERT_GENTPROTR_BASIC0( sumsqv )
+INSERT_GENTPROTR_BASIC( sumsqv )
+
+// -----------------------------------------------------------------------------
+
+// Operations with basic interfaces only.
+
+#ifdef BLIS_TAPI_BASIC
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+             conj_t conjchi, \
+       const ctype* chi, \
+       const ctype* psi, \
+             bool*  is_eq  \
+     );
+
+INSERT_GENTPROT_BASIC( eqsc )
 
 
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+      ( \
+              conj_t conjx, \
+              dim_t  n, \
+        const ctype* x, inc_t incx, \
+        const ctype* y, inc_t incy, \
+              bool*  is_eq  \
+      );
+
+INSERT_GENTPROT_BASIC( eqv )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+             doff_t  diagoffx, \
+             diag_t  diagx, \
+             uplo_t  uplox, \
+             trans_t transx, \
+             dim_t   m, \
+             dim_t   n, \
+       const ctype*  x, inc_t rs_x, inc_t cs_x, \
+       const ctype*  y, inc_t rs_y, inc_t cs_y, \
+             bool*   is_eq  \
+     );
+
+INSERT_GENTPROT_BASIC( eqm )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+       const ctype* chi, \
+       const ctype* psi, \
+             bool*  is  \
+     );
+
+INSERT_GENTPROT_BASIC( ltsc )
+INSERT_GENTPROT_BASIC( ltesc )
+INSERT_GENTPROT_BASIC( gtsc )
+INSERT_GENTPROT_BASIC( gtesc )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+       const char* s1, \
+             dim_t n, \
+       const void* x, inc_t incx, \
+       const char* format, \
+       const char* s2  \
+     );
+
+INSERT_GENTPROT_BASIC_I( printv )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+       const char* s1, \
+             dim_t m, \
+             dim_t n, \
+       const void* x, inc_t rs_x, inc_t cs_x, \
+       const char* format, \
+       const char* s2  \
+     );
+
+INSERT_GENTPROT_BASIC_I( printm )
+
+#endif // #ifdef BLIS_TAPI_BASIC
+
