@@ -49,7 +49,7 @@ void PASTEMAC(ch,varname) \
        rntm_t*  rntm  \
      );
 
-INSERT_GENTPROTR_BASIC0( asumv_unb_var1 )
+INSERT_GENTPROTR_BASIC( asumv_unb_var1 )
 
 
 #undef  GENTPROT
@@ -64,9 +64,9 @@ void PASTEMAC(ch,varname) \
        rntm_t* rntm  \
      );
 
-INSERT_GENTPROT_BASIC0( mkherm_unb_var1 )
-INSERT_GENTPROT_BASIC0( mksymm_unb_var1 )
-INSERT_GENTPROT_BASIC0( mktrim_unb_var1 )
+INSERT_GENTPROT_BASIC( mkherm_unb_var1 )
+INSERT_GENTPROT_BASIC( mksymm_unb_var1 )
+INSERT_GENTPROT_BASIC( mktrim_unb_var1 )
 
 
 #undef  GENTPROTR
@@ -81,9 +81,9 @@ void PASTEMAC(ch,varname) \
        rntm_t*  rntm  \
      );
 
-INSERT_GENTPROTR_BASIC0( norm1v_unb_var1 )
-INSERT_GENTPROTR_BASIC0( normfv_unb_var1 )
-INSERT_GENTPROTR_BASIC0( normiv_unb_var1 )
+INSERT_GENTPROTR_BASIC( norm1v_unb_var1 )
+INSERT_GENTPROTR_BASIC( normfv_unb_var1 )
+INSERT_GENTPROTR_BASIC( normiv_unb_var1 )
 
 
 #undef  GENTPROTR
@@ -102,42 +102,9 @@ void PASTEMAC(ch,varname) \
        rntm_t*  rntm  \
      );
 
-INSERT_GENTPROTR_BASIC0( norm1m_unb_var1 )
-INSERT_GENTPROTR_BASIC0( normfm_unb_var1 )
-INSERT_GENTPROTR_BASIC0( normim_unb_var1 )
-
-
-#undef  GENTPROT
-#define GENTPROT( ctype, ch, opname ) \
-\
-BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
-     ( \
-       FILE*  file, \
-       char*  s1, \
-       dim_t  n, \
-       ctype* x, inc_t incx, \
-       char*  format, \
-       char*  s2  \
-     );
-
-INSERT_GENTPROT_BASIC0_I( fprintv )
-
-
-#undef  GENTPROT
-#define GENTPROT( ctype, ch, opname ) \
-\
-BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
-     ( \
-       FILE*  file, \
-       char*  s1, \
-       dim_t  m, \
-       dim_t  n, \
-       ctype* x, inc_t rs_x, inc_t cs_x, \
-       char*  format, \
-       char*  s2  \
-     );
-
-INSERT_GENTPROT_BASIC0_I( fprintm )
+INSERT_GENTPROTR_BASIC( norm1m_unb_var1 )
+INSERT_GENTPROTR_BASIC( normfm_unb_var1 )
+INSERT_GENTPROTR_BASIC( normim_unb_var1 )
 
 
 #undef  GENTPROT
@@ -151,8 +118,8 @@ void PASTEMAC(ch,varname) \
        rntm_t* rntm  \
      );
 
-INSERT_GENTPROT_BASIC0( randv_unb_var1 )
-INSERT_GENTPROT_BASIC0( randnv_unb_var1 )
+INSERT_GENTPROT_BASIC( randv_unb_var1 )
+INSERT_GENTPROT_BASIC( randnv_unb_var1 )
 
 
 #undef  GENTPROT
@@ -169,8 +136,8 @@ void PASTEMAC(ch,varname) \
        rntm_t* rntm  \
      );
 
-INSERT_GENTPROT_BASIC0( randm_unb_var1 )
-INSERT_GENTPROT_BASIC0( randnm_unb_var1 )
+INSERT_GENTPROT_BASIC( randm_unb_var1 )
+INSERT_GENTPROT_BASIC( randnm_unb_var1 )
 
 
 #undef  GENTPROTR
@@ -186,5 +153,72 @@ void PASTEMAC(ch,varname) \
        rntm_t*  rntm  \
      );
 
-INSERT_GENTPROTR_BASIC0( sumsqv_unb_var1 )
+INSERT_GENTPROTR_BASIC( sumsqv_unb_var1 )
+
+// -----------------------------------------------------------------------------
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, varname ) \
+\
+bool PASTEMAC(ch,varname) \
+     ( \
+       conj_t conjx, \
+       dim_t  n, \
+       ctype* x, inc_t incx, \
+       ctype* y, inc_t incy  \
+     );
+
+INSERT_GENTPROT_BASIC( eqv_unb_var1 )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, varname ) \
+\
+bool PASTEMAC(ch,varname) \
+     ( \
+       doff_t  diagoffx, \
+       diag_t  diagx, \
+       uplo_t  uplox, \
+       trans_t transx, \
+       dim_t   m, \
+       dim_t   n, \
+       ctype*  x, inc_t rs_x, inc_t cs_x, \
+       ctype*  y, inc_t rs_y, inc_t cs_y  \
+     );
+
+INSERT_GENTPROT_BASIC( eqm_unb_var1 )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+             FILE*  file, \
+       const char*  s1, \
+             dim_t  n, \
+       const ctype* x, inc_t incx, \
+       const char*  format, \
+       const char*  s2  \
+     );
+
+INSERT_GENTPROT_BASIC_I( fprintv )
+
+
+#undef  GENTPROT
+#define GENTPROT( ctype, ch, opname ) \
+\
+BLIS_EXPORT_BLIS void PASTEMAC(ch,opname) \
+     ( \
+             FILE*  file, \
+       const char*  s1, \
+             dim_t  m, \
+             dim_t  n, \
+       const ctype* x, inc_t rs_x, inc_t cs_x, \
+       const char*  format, \
+       const char*  s2  \
+     );
+
+INSERT_GENTPROT_BASIC_I( fprintm )
+
 
