@@ -36,16 +36,20 @@
 
 void bli_ddotv_bgq_int
      (
-       conj_t           conjx,
-       conj_t           conjy,
-       dim_t            n,
-       double* restrict x, inc_t incx,
-       double* restrict y, inc_t incy,
-       double* restrict rho,
-       cntx_t* restrict cntx
+             conj_t  conjx,
+             conj_t  conjy,
+             dim_t   n,
+       const void*   x0, inc_t incx,
+       const void*   y0, inc_t incy,
+             void*   rho0,
+       const cntx_t* cntx
      )
 {
-	bool   use_ref = FALSE;
+	const double* x   = x0;
+	const double* y   = y0;
+	const double* rho = rho0;
+
+	bool use_ref = FALSE;
 
 	// If the vector lengths are zero, set rho to zero and return.
 	if ( bli_zero_dim1( n ) ) {
@@ -91,7 +95,7 @@ void bli_ddotv_bgq_int
     {
         rhos += x[4*n_run + i] * y[4*n_run + i];
     }
-	
+
     *rho = rhos;
 }
 
