@@ -108,15 +108,15 @@ static int32_t offsets[32] __attribute__((aligned(64))) =
 
 void bli_dpackm_knl_asm_8xk
      (
-       conj_t           conja,
-       pack_t           schema,
-       dim_t            cdim_,
-       dim_t            n_,
-       dim_t            n_max_,
-       double* restrict kappa_,
-       double* restrict a_, inc_t inca_, inc_t lda_,
-       double* restrict p_,              inc_t ldp_,
-       cntx_t* restrict cntx
+             conj_t  conja,
+             pack_t  schema,
+             dim_t   cdim_,
+             dim_t   n_,
+             dim_t   n_max_,
+       const void*   kappa_,
+       const void*   a_, inc_t inca_, inc_t lda_,
+             void*   p_,              inc_t ldp_,
+       const cntx_t* cntx
      )
 {
     const int32_t* offsetPtr = &offsets[0];
@@ -330,7 +330,7 @@ void bli_dpackm_knl_asm_8xk
 			const dim_t      i      = cdim;
 			const dim_t      m_edge = mnr - i;
 			const dim_t      n_edge = n_max;
-			double* restrict p_edge = p + (i  )*1;
+			double* restrict p_edge = ( double* )p + (i  )*1;
 
 			bli_dset0s_mxn
 			(
@@ -346,7 +346,7 @@ void bli_dpackm_knl_asm_8xk
 		const dim_t      j      = n;
 		const dim_t      m_edge = mnr;
 		const dim_t      n_edge = n_max - j;
-		double* restrict p_edge = p + (j  )*ldp;
+		double* restrict p_edge = ( double* )p + (j  )*ldp;
 
 		bli_dset0s_mxn
 		(
@@ -359,15 +359,15 @@ void bli_dpackm_knl_asm_8xk
 
 void bli_dpackm_knl_asm_24xk
      (
-       conj_t           conja,
-       pack_t           schema,
-       dim_t            cdim_,
-       dim_t            n_,
-       dim_t            n_max_,
-       double* restrict kappa_,
-       double* restrict a_, inc_t inca_, inc_t lda_,
-       double* restrict p_,              inc_t ldp_,
-       cntx_t* restrict cntx
+             conj_t  conja,
+             pack_t  schema,
+             dim_t   cdim_,
+             dim_t   n_,
+             dim_t   n_max_,
+       const void*   kappa_,
+       const void*   a_, inc_t inca_, inc_t lda_,
+             void*   p_,              inc_t ldp_,
+       const cntx_t* cntx
      )
 {
     const int32_t* offsetPtr = &offsets[0];
@@ -634,7 +634,7 @@ void bli_dpackm_knl_asm_24xk
 			const dim_t      i      = cdim;
 			const dim_t      m_edge = mnr - i;
 			const dim_t      n_edge = n_max;
-			double* restrict p_edge = p + (i  )*1;
+			double* restrict p_edge = ( double* )p + (i  )*1;
 
 			bli_dset0s_mxn
 			(
@@ -650,7 +650,7 @@ void bli_dpackm_knl_asm_24xk
 		const dim_t      j      = n;
 		const dim_t      m_edge = mnr;
 		const dim_t      n_edge = n_max - j;
-		double* restrict p_edge = p + (j  )*ldp;
+		double* restrict p_edge = ( double* )p + (j  )*ldp;
 
 		bli_dset0s_mxn
 		(
