@@ -110,15 +110,15 @@ static int32_t offsets[32] __attribute__((aligned(64))) =
 
 void bli_spackm_knl_asm_16xk
      (
-       conj_t           conja,
-       pack_t           schema,
-       dim_t            cdim_,
-       dim_t            n_,
-       dim_t            n_max_,
-       void*   restrict kappa_,
-       void*   restrict a_, inc_t inca_, inc_t lda_,
-       void*   restrict p_,              inc_t ldp_,
-       cntx_t* restrict cntx
+             conj_t  conja,
+             pack_t  schema,
+             dim_t   cdim_,
+             dim_t   n_,
+             dim_t   n_max_,
+       const void*   kappa_,
+       const void*   a_, inc_t inca_, inc_t lda_,
+             void*   p_,              inc_t ldp_,
+       const cntx_t* cntx
      )
 {
     const int32_t* offsetPtr = &offsets[0];
@@ -348,7 +348,7 @@ void bli_spackm_knl_asm_16xk
 			const dim_t      i      = cdim;
 			const dim_t      m_edge = mnr - i;
 			const dim_t      n_edge = n_max;
-			float*  restrict p_edge = p + (i  )*1;
+			float*  restrict p_edge = ( float* )p + (i  )*1;
 
 			bli_sset0s_mxn
 			(
@@ -364,7 +364,7 @@ void bli_spackm_knl_asm_16xk
 		const dim_t      j      = n;
 		const dim_t      m_edge = mnr;
 		const dim_t      n_edge = n_max - j;
-		float*  restrict p_edge = p + (j  )*ldp;
+		float*  restrict p_edge = ( float* )p + (j  )*ldp;
 
 		bli_sset0s_mxn
 		(
@@ -377,15 +377,15 @@ void bli_spackm_knl_asm_16xk
 
 void bli_spackm_knl_asm_24xk
      (
-       conj_t           conja,
-       pack_t           schema,
-       dim_t            cdim_,
-       dim_t            n_,
-       dim_t            n_max_,
-       void*   restrict kappa_,
-       void*   restrict a_, inc_t inca_, inc_t lda_,
-       void*   restrict p_,              inc_t ldp_,
-       cntx_t* restrict cntx
+             conj_t  conja,
+             pack_t  schema,
+             dim_t   cdim_,
+             dim_t   n_,
+             dim_t   n_max_,
+       const void*   kappa_,
+       const void*   a_, inc_t inca_, inc_t lda_,
+             void*   p_,              inc_t ldp_,
+       const cntx_t* cntx
      )
 {
     const int32_t* offsetPtr = &offsets[0];
@@ -651,7 +651,7 @@ void bli_spackm_knl_asm_24xk
 			const dim_t      i      = cdim;
 			const dim_t      m_edge = mnr - i;
 			const dim_t      n_edge = n_max;
-			float*  restrict p_edge = p + (i  )*1;
+			float*  restrict p_edge = ( float* )p + (i  )*1;
 
 			bli_sset0s_mxn
 			(
@@ -667,7 +667,7 @@ void bli_spackm_knl_asm_24xk
 		const dim_t      j      = n;
 		const dim_t      m_edge = mnr;
 		const dim_t      n_edge = n_max - j;
-		float*  restrict p_edge = p + (j  )*ldp;
+		float*  restrict p_edge = ( float* )p + (j  )*ldp;
 
 		bli_sset0s_mxn
 		(
