@@ -45,39 +45,36 @@ typedef union
 
 void bli_ddotaxpyv_penryn_int
      (
-       conj_t           conjxt,
-       conj_t           conjx,
-       conj_t           conjy,
-       dim_t            n,
-       double* restrict alpha,
-       double* restrict x, inc_t incx,
-       double* restrict y, inc_t incy,
-       double* restrict rho,
-       double* restrict z, inc_t incz,
-       cntx_t* restrict cntx
+             conj_t  conjxt,
+             conj_t  conjx,
+             conj_t  conjy,
+             dim_t   n,
+       const void*   alpha,
+       const void*   x, inc_t incx,
+       const void*   y, inc_t incy,
+             void*   rho,
+             void*   z, inc_t incz,
+       const cntx_t* cntx
      )
 {
-	double*  restrict alpha_cast = alpha;
-	double*  restrict x_cast     = x;
-	double*  restrict y_cast     = y;
-	double*  restrict rho_cast   = rho;
-	double*  restrict z_cast     = z;
+	const double*  restrict alpha_cast = alpha;
+	const double*  restrict x_cast     = x;
+	const double*  restrict y_cast     = y;
+	      double*  restrict rho_cast   = rho;
+	      double*  restrict z_cast     = z;
 
-	dim_t             n_pre;
-	dim_t             n_run;
-	dim_t             n_left;
+	      dim_t             n_pre;
+	      dim_t             n_run;
+	      dim_t             n_left;
 
-	double*  restrict chi1;
-	double*  restrict psi1;
-	double*  restrict zeta1;
-	double            alpha1c, chi1c, psi1c, rho1c;
-	dim_t             i;
-	//inc_t             stepx, stepy, stepz;
+	      double            alpha1c, chi1c, psi1c, rho1c;
+	      dim_t             i;
+	      //inc_t             stepx, stepy, stepz;
 
-	v2df_t            alphav, rhov;
-	v2df_t            x1v, y1v, z1v;
+	      v2df_t            alphav, rhov;
+	      v2df_t            x1v, y1v, z1v;
 
-	bool              use_ref = FALSE;
+	      bool              use_ref = FALSE;
 
 	// If the vector lengths are zero, set rho to zero and return.
 	if ( bli_zero_dim1( n ) )
@@ -112,7 +109,8 @@ void bli_ddotaxpyv_penryn_int
 	// Call the reference implementation if needed.
 	if ( use_ref == TRUE )
 	{
-		ddotaxpyv_ker_ft f = bli_cntx_get_l1f_ker_dt( BLIS_DOUBLE, BLIS_DOTAXPYV_KER, cntx );
+		#if 0
+		dotaxpyv_ker_ft f = bli_cntx_get_ukr_dt( BLIS_DOUBLE, BLIS_DOTAXPYV_KER, cntx );
 
 		f
 		(
@@ -127,6 +125,8 @@ void bli_ddotaxpyv_penryn_int
 		  z, incz,
 		  cntx
 		);
+		#endif
+		bli_abort();
 		return;
 	}
 
@@ -142,9 +142,9 @@ void bli_ddotaxpyv_penryn_int
 
 	alpha1c = *alpha_cast;
 
-	chi1  = x_cast;
-	psi1  = y_cast;
-	zeta1 = z_cast;
+	const double* restrict chi1  = x_cast;
+	const double* restrict psi1  = y_cast;
+	      double* restrict zeta1 = z_cast;
 
 	if ( n_pre == 1 )
 	{
