@@ -149,22 +149,24 @@
     VMOVAPD(ZMM(0), MEM(RAX,(16*n+0)*8)) \
     VMOVAPD(ZMM(1), MEM(RAX,(16*n+8)*8))
 
+#if 0
 //This is an array used for the scatter/gather instructions.
 static int64_t offsets[16] __attribute__((aligned(64))) =
     { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9,10,11,12,13,14,15};
+#endif
 
 void bli_dgemm_skx_asm_16x14
      (
-       dim_t            m,
-       dim_t            n,
-       dim_t            k_,
-       double* restrict alpha,
-       double* restrict a,
-       double* restrict b,
-       double* restrict beta,
-       double* restrict c, inc_t rs_c_, inc_t cs_c_,
-       auxinfo_t*       data,
-       cntx_t* restrict cntx
+             dim_t      m,
+             dim_t      n,
+             dim_t      k_,
+       const void*      alpha,
+       const void*      a,
+       const void*      b,
+       const void*      beta,
+             void*      c, inc_t rs_c_, inc_t cs_c_,
+             auxinfo_t* data,
+       const cntx_t*    cntx
      )
 {
     (void)data;
