@@ -57,14 +57,18 @@ typedef union
 
 void bli_saxpyv_zen_int
      (
-       conj_t           conjx,
-       dim_t            n,
-       float*  restrict alpha,
-       float*  restrict x, inc_t incx,
-       float*  restrict y, inc_t incy,
-       cntx_t* restrict cntx
+             conj_t  conjx,
+             dim_t   n,
+       const void*   alpha0,
+       const void*   x0, inc_t incx,
+             void*   y0, inc_t incy,
+       const cntx_t* cntx
      )
 {
+	const float*     alpha = alpha0;
+	const float*     x     = x0;
+	      float*     y     = y0;
+
 	const dim_t      n_elem_per_reg = 8;
 	const dim_t      n_iter_unroll  = 4;
 
@@ -72,9 +76,6 @@ void bli_saxpyv_zen_int
 	dim_t            n_viter;
 	dim_t            n_left;
 
-	float*  restrict x0;
-	float*  restrict y0;
-
 	v8sf_t           alphav;
 	v8sf_t           x0v, x1v, x2v, x3v;
 	v8sf_t           y0v, y1v, y2v, y3v;
@@ -97,8 +98,8 @@ void bli_saxpyv_zen_int
 	}
 
 	// Initialize local pointers.
-	x0 = x;
-	y0 = y;
+	const float* restrict xp = x;
+	      float* restrict yp = y;
 
 	// Broadcast the alpha scalar to all elements of a vector register.
 	alphav.v = _mm256_broadcast_ss( alpha );
@@ -108,17 +109,17 @@ void bli_saxpyv_zen_int
 	for ( i = 0; i < n_viter; ++i )
 	{
 		// Load the input values.
-		y0v.v = _mm256_loadu_ps( y0 + 0*n_elem_per_reg );
-		x0v.v = _mm256_loadu_ps( x0 + 0*n_elem_per_reg );
+		y0v.v = _mm256_loadu_ps( yp + 0*n_elem_per_reg );
+		x0v.v = _mm256_loadu_ps( xp + 0*n_elem_per_reg );
 
-		y1v.v = _mm256_loadu_ps( y0 + 1*n_elem_per_reg );
-		x1v.v = _mm256_loadu_ps( x0 + 1*n_elem_per_reg );
+		y1v.v = _mm256_loadu_ps( yp + 1*n_elem_per_reg );
+		x1v.v = _mm256_loadu_ps( xp + 1*n_elem_per_reg );
 
-		y2v.v = _mm256_loadu_ps( y0 + 2*n_elem_per_reg );
-		x2v.v = _mm256_loadu_ps( x0 + 2*n_elem_per_reg );
+		y2v.v = _mm256_loadu_ps( yp + 2*n_elem_per_reg );
+		x2v.v = _mm256_loadu_ps( xp + 2*n_elem_per_reg );
 
-		y3v.v = _mm256_loadu_ps( y0 + 3*n_elem_per_reg );
-		x3v.v = _mm256_loadu_ps( x0 + 3*n_elem_per_reg );
+		y3v.v = _mm256_loadu_ps( yp + 3*n_elem_per_reg );
+		x3v.v = _mm256_loadu_ps( xp + 3*n_elem_per_reg );
 
 		// perform : y += alpha * x;
 		y0v.v = _mm256_fmadd_ps( alphav.v, x0v.v, y0v.v );
@@ -127,13 +128,13 @@ void bli_saxpyv_zen_int
 		y3v.v = _mm256_fmadd_ps( alphav.v, x3v.v, y3v.v );
 
 		// Store the output.
-		_mm256_storeu_ps( (y0 + 0*n_elem_per_reg), y0v.v );
-		_mm256_storeu_ps( (y0 + 1*n_elem_per_reg), y1v.v );
-		_mm256_storeu_ps( (y0 + 2*n_elem_per_reg), y2v.v );
-		_mm256_storeu_ps( (y0 + 3*n_elem_per_reg), y3v.v );
+		_mm256_storeu_ps( (yp + 0*n_elem_per_reg), y0v.v );
+		_mm256_storeu_ps( (yp + 1*n_elem_per_reg), y1v.v );
+		_mm256_storeu_ps( (yp + 2*n_elem_per_reg), y2v.v );
+		_mm256_storeu_ps( (yp + 3*n_elem_per_reg), y3v.v );
 
-		x0 += n_elem_per_reg * n_iter_unroll;
-		y0 += n_elem_per_reg * n_iter_unroll;
+		xp += n_elem_per_reg * n_iter_unroll;
+		yp += n_elem_per_reg * n_iter_unroll;
 	}
 
 	// Issue vzeroupper instruction to clear upper lanes of ymm registers.
@@ -148,12 +149,12 @@ void bli_saxpyv_zen_int
 	// If there are leftover iterations, perform them with scalar code.
 	for ( i = 0; i < n_left; ++i )
 	{
-		const float x0c = *x0;
+		const float x0c = *xp;
 
-		*y0 += alphac * x0c;
+		*yp += alphac * x0c;
 
-		x0 += incx;
-		y0 += incy;
+		xp += incx;
+		yp += incy;
 	}
 }
 
@@ -161,14 +162,18 @@ void bli_saxpyv_zen_int
 
 void bli_daxpyv_zen_int
      (
-       conj_t           conjx,
-       dim_t            n,
-       double* restrict alpha,
-       double* restrict x, inc_t incx,
-       double* restrict y, inc_t incy,
-       cntx_t* restrict cntx
+             conj_t  conjx,
+             dim_t   n,
+       const void*   alpha0,
+       const void*   x0, inc_t incx,
+             void*   y0, inc_t incy,
+       const cntx_t* cntx
      )
 {
+	const double*     alpha = alpha0;
+	const double*     x     = x0;
+	      double*     y     = y0;
+
 	const dim_t       n_elem_per_reg = 4;
 	const dim_t       n_iter_unroll  = 4;
 
@@ -176,9 +181,6 @@ void bli_daxpyv_zen_int
 	dim_t             n_viter;
 	dim_t             n_left;
 
-	double*  restrict x0;
-	double*  restrict y0;
-
 	v4df_t            alphav;
 	v4df_t            x0v, x1v, x2v, x3v;
 	v4df_t            y0v, y1v, y2v, y3v;
@@ -201,8 +203,8 @@ void bli_daxpyv_zen_int
 	}
 
 	// Initialize local pointers.
-	x0 = x;
-	y0 = y;
+	const double* restrict xp = x;
+	      double* restrict yp = y;
 
 	// Broadcast the alpha scalar to all elements of a vector register.
 	alphav.v = _mm256_broadcast_sd( alpha );
@@ -212,17 +214,17 @@ void bli_daxpyv_zen_int
 	for ( i = 0; i < n_viter; ++i )
 	{
 		// Load the input values.
-		y0v.v = _mm256_loadu_pd( y0 + 0*n_elem_per_reg );
-		x0v.v = _mm256_loadu_pd( x0 + 0*n_elem_per_reg );
+		y0v.v = _mm256_loadu_pd( yp + 0*n_elem_per_reg );
+		x0v.v = _mm256_loadu_pd( xp + 0*n_elem_per_reg );
 
-		y1v.v = _mm256_loadu_pd( y0 + 1*n_elem_per_reg );
-		x1v.v = _mm256_loadu_pd( x0 + 1*n_elem_per_reg );
+		y1v.v = _mm256_loadu_pd( yp + 1*n_elem_per_reg );
+		x1v.v = _mm256_loadu_pd( xp + 1*n_elem_per_reg );
 
-		y2v.v = _mm256_loadu_pd( y0 + 2*n_elem_per_reg );
-		x2v.v = _mm256_loadu_pd( x0 + 2*n_elem_per_reg );
+		y2v.v = _mm256_loadu_pd( yp + 2*n_elem_per_reg );
+		x2v.v = _mm256_loadu_pd( xp + 2*n_elem_per_reg );
 
-		y3v.v = _mm256_loadu_pd( y0 + 3*n_elem_per_reg );
-		x3v.v = _mm256_loadu_pd( x0 + 3*n_elem_per_reg );
+		y3v.v = _mm256_loadu_pd( yp + 3*n_elem_per_reg );
+		x3v.v = _mm256_loadu_pd( xp + 3*n_elem_per_reg );
 
 		// perform : y += alpha * x;
 		y0v.v = _mm256_fmadd_pd( alphav.v, x0v.v, y0v.v );
@@ -231,13 +233,13 @@ void bli_daxpyv_zen_int
 		y3v.v = _mm256_fmadd_pd( alphav.v, x3v.v, y3v.v );
 
 		// Store the output.
-		_mm256_storeu_pd( (y0 + 0*n_elem_per_reg), y0v.v );
-		_mm256_storeu_pd( (y0 + 1*n_elem_per_reg), y1v.v );
-		_mm256_storeu_pd( (y0 + 2*n_elem_per_reg), y2v.v );
-		_mm256_storeu_pd( (y0 + 3*n_elem_per_reg), y3v.v );
+		_mm256_storeu_pd( (yp + 0*n_elem_per_reg), y0v.v );
+		_mm256_storeu_pd( (yp + 1*n_elem_per_reg), y1v.v );
+		_mm256_storeu_pd( (yp + 2*n_elem_per_reg), y2v.v );
+		_mm256_storeu_pd( (yp + 3*n_elem_per_reg), y3v.v );
 
-		x0 += n_elem_per_reg * n_iter_unroll;
-		y0 += n_elem_per_reg * n_iter_unroll;
+		xp += n_elem_per_reg * n_iter_unroll;
+		yp += n_elem_per_reg * n_iter_unroll;
 	}
 
 	// Issue vzeroupper instruction to clear upper lanes of ymm registers.
@@ -252,12 +254,12 @@ void bli_daxpyv_zen_int
 	// If there are leftover iterations, perform them with scalar code.
 	for ( i = 0; i < n_left; ++i )
 	{
-		const double x0c = *x0;
+		const double x0c = *xp;
 
-		*y0 += alphac * x0c;
+		*yp += alphac * x0c;
 
-		x0 += incx;
-		y0 += incy;
+		xp += incx;
+		yp += incy;
 	}
 }
 
