@@ -39,29 +39,33 @@
 \
 void PASTEMAC3(ch,opname,arch,suf) \
      ( \
-       conj_t           conjx, \
-       dim_t            n, \
-       ctype*  restrict x, inc_t incx, \
-       ctype*  restrict beta, \
-       ctype*  restrict y, inc_t incy, \
-       cntx_t* restrict cntx  \
+             conj_t  conjx, \
+             dim_t   n, \
+       const void*   x0, inc_t incx, \
+       const void*   beta0, \
+             void*   y0, inc_t incy, \
+       const cntx_t* cntx  \
      ) \
 { \
 	if ( bli_zero_dim1( n ) ) return; \
+\
+	const ctype* x    = x0; \
+	const ctype* beta = beta0; \
+	      ctype* y    = y0; \
 \
 	/* If beta is zero, use copyv. */ \
 	if ( PASTEMAC(ch,eq0)( *beta ) ) \
 	{ \
 		/* Query the context for the kernel function pointer. */ \
-		const num_t              dt      = PASTEMAC(ch,type); \
-		PASTECH(ch,copyv_ker_ft) copyv_p = bli_cntx_get_l1v_ker_dt( dt, BLIS_COPYV_KER, cntx ); \
+		const num_t  dt      = PASTEMAC(ch,type); \
+		copyv_ker_ft copyv_p = bli_cntx_get_ukr_dt( dt, BLIS_COPYV_KER, cntx ); \
 \
 		copyv_p \
 		( \
 		  conjx, \
 		  n, \
-		  x, incx, \
-		  y, incy, \
+		  x0, incx, \
+		  y0, incy, \
 		  cntx  \
 		); \
 		return; \
@@ -70,15 +74,15 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	else if ( PASTEMAC(ch,eq1)( *beta ) ) \
 	{ \
 		/* Query the context for the kernel function pointer. */ \
-		const num_t             dt     = PASTEMAC(ch,type); \
-		PASTECH(ch,addv_ker_ft) addv_p = bli_cntx_get_l1v_ker_dt( dt, BLIS_ADDV_KER, cntx ); \
+		const num_t dt     = PASTEMAC(ch,type); \
+		addv_ker_ft addv_p = bli_cntx_get_ukr_dt( dt, BLIS_ADDV_KER, cntx ); \
 \
 		addv_p \
 		( \
 		  conjx, \
 		  n, \
-		  x, incx, \
-		  y, incy, \
+		  x0, incx, \
+		  y0, incy, \
 		  cntx  \
 		); \
 		return; \
@@ -128,5 +132,5 @@ void PASTEMAC3(ch,opname,arch,suf) \
 	} \
 }
 
-INSERT_GENTFUNC_BASIC2( xpbyv, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
+INSERT_GENTFUNC_BASIC( xpbyv, BLIS_CNAME_INFIX, BLIS_REF_SUFFIX )
 
