@@ -157,7 +157,7 @@ void PASTECH2(bls_,ch,varname) \
 	   function pointer type. */ \
 	/*
 	PASTECH(ch,gemm_ukr_ft) \
-               gemm_ukr = bli_cntx_get_l3_nat_ukr_dt( dt, BLIS_GEMM_UKR, cntx ); \
+               gemm_ukr = bli_cntx_get_ukr_dt( dt, BLIS_GEMM_UKR, cntx ); \
 	*/ \
 \
 	/* Temporary C buffer for edge cases. Note that the strides of this
@@ -168,7 +168,7 @@ void PASTECH2(bls_,ch,varname) \
 	ctype       ct[ BLIS_STACK_BUF_MAX_SIZE \
 	                / sizeof( ctype ) ] \
 	                __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const bool col_pref = bli_cntx_l3_nat_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
+	const bool col_pref = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
 	const inc_t rs_ct   = ( col_pref ? 1 : NR ); \
 	const inc_t cs_ct   = ( col_pref ? MR : 1 ); \
 	*/ \
@@ -374,8 +374,8 @@ void PASTECH2(bls_,ch,varname) \
 				/* Query the number of threads and thread ids for the JR loop.
 				   NOTE: These values are only needed when computing the next
 				   micropanel of B. */ \
-				const dim_t jr_nt  = bli_thread_n_way( thread_jr ); \
-				const dim_t jr_tid = bli_thread_work_id( thread_jr ); \
+				const dim_t jr_nt  = bli_thrinfo_n_way( thread_jr ); \
+				const dim_t jr_tid = bli_thrinfo_work_id( thread_jr ); \
 \
 				/* Compute number of primary and leftover components of the JR loop. */ \
 				dim_t jr_iter = ( nc_cur + NR - 1 ) / NR; \
@@ -404,8 +404,8 @@ void PASTECH2(bls_,ch,varname) \
 					/* Query the number of threads and thread ids for the IR loop.
 					   NOTE: These values are only needed when computing the next
 					   micropanel of A. */ \
-					const dim_t ir_nt  = bli_thread_n_way( thread_ir ); \
-					const dim_t ir_tid = bli_thread_work_id( thread_ir ); \
+					const dim_t ir_nt  = bli_thrinfo_n_way( thread_ir ); \
+					const dim_t ir_tid = bli_thrinfo_work_id( thread_ir ); \
 \
 					/* Compute number of primary and leftover components of the IR loop. */ \
 					dim_t ir_iter = ( mc_cur + MR - 1 ) / MR; \
@@ -464,7 +464,7 @@ void PASTECH2(bls_,ch,varname) \
 			/* This barrier is needed to prevent threads from starting to pack
 			   the next row panel of B before the current row panel is fully
 			   computed upon. */ \
-			bli_thread_barrier( thread_pb ); \
+			bli_thrinfo_barrier( thread_pb ); \
 		} \
 	} \
 \
@@ -524,7 +524,7 @@ void PASTECH2(bls_,ch,varname) \
 	/* Query the context for the microkernel address and cast it to its
 	   function pointer type. */ \
 	PASTECH(ch,gemm_ukr_ft) \
-               gemm_ukr = bli_cntx_get_l3_nat_ukr_dt( dt, BLIS_GEMM_UKR, cntx ); \
+               gemm_ukr = bli_cntx_get_ukr_dt( dt, BLIS_GEMM_UKR, cntx ); \
 \
 	/* Temporary C buffer for edge cases. Note that the strides of this
 	   temporary buffer are set so that they match the storage of the
@@ -533,7 +533,7 @@ void PASTECH2(bls_,ch,varname) \
 	ctype       ct[ BLIS_STACK_BUF_MAX_SIZE \
 	                / sizeof( ctype ) ] \
 	                __attribute__((aligned(BLIS_STACK_BUF_ALIGN_SIZE))); \
-	const bool col_pref = bli_cntx_l3_nat_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
+	const bool col_pref = bli_cntx_ukr_prefers_cols_dt( dt, BLIS_GEMM_UKR, cntx ); \
 	const inc_t rs_ct   = ( col_pref ? 1 : NR ); \
 	const inc_t cs_ct   = ( col_pref ? MR : 1 ); \
 \
