@@ -34,9 +34,13 @@
 
 #include <unistd.h>
 #include "blis.h"
+#include "test_utils.h"
 
 //#define PRINT
 
+static const char* LOCAL_OPNAME_STR = "hemm";
+static const char* LOCAL_PC_STR     = "ll";
+
 int main( int argc, char** argv )
 {
 	obj_t    a, b, c;
@@ -59,54 +63,42 @@ int main( int argc, char** argv )
 	double   dtime_save;
 	double   gflops;
 
-	//bli_init();
-
-	//bli_error_checking_level_set( BLIS_NO_ERROR_CHECKING );
-
-	n_repeats = 3;
-
-	dt      = DT;
-
-	ind     = IND;
-
-	p_begin = P_BEGIN;
-	p_max   = P_MAX;
-	p_inc   = P_INC;
-
-	m_input = -1;
-	n_input = -1;
-
+	params_t params;
 
 	// Supress compiler warnings about unused variable 'ind'.
 	( void )ind;
 
-#if 0
 
-	cntx_t* cntx;
+	//bli_init();
 
-	ind_t ind_mod = ind;
+	//bli_error_checking_level_set( BLIS_NO_ERROR_CHECKING );
 
-	// Initialize a context for the current induced method and datatype.
-	cntx = bli_gks_query_ind_cntx( ind_mod, dt );
+	// Parse the command line options into strings, integers, enums,
+	// and doubles, as appropriate.
+	parse_cl_params( argc, argv, init_def_params, &params );
 
-	// Set k to the kc blocksize for the current datatype.
-	k_input = bli_cntx_get_blksz_def_dt( dt, BLIS_KC, cntx );
+	dt        = params.dt;
 
-#elif 1
+	ind       = params.im;
 
-	//k_input = 256;
+	p_begin   = params.sta;
+	p_max     = params.end;
+	p_inc     = params.inc;
 
-#endif
+	m_input   = params.m;
+	n_input   = params.n;
 
-	// Choose the char corresponding to the requested datatype.
-	if      ( bli_is_float( dt ) )    dt_ch = 's';
-	else if ( bli_is_double( dt ) )   dt_ch = 'd';
-	else if ( bli_is_scomplex( dt ) ) dt_ch = 'c';
-	else                              dt_ch = 'z';
+	n_repeats = params.nr;
 
-	side  = BLIS_LEFT;
-	uploa = BLIS_LOWER;
 
+	// Map the datatype to its corresponding char.
+	bli_param_map_blis_to_char_dt( dt, &dt_ch );
+
+	// Map the parameter chars to their corresponding BLIS enum type values.
+	bli_param_map_char_to_blis_side( params.pc_str[0], &side );
+	bli_param_map_char_to_blis_uplo( params.pc_str[1], &uploa );
+
+	// Map the BLIS enum type values to their corresponding BLAS chars.
 	bli_param_map_blis_to_netlib_side( side, &f77_side );
 	bli_param_map_blis_to_netlib_uplo( uploa, &f77_uploa );
 
@@ -114,8 +106,8 @@ int main( int argc, char** argv )
 	// matlab allocates space for the entire array once up-front.
 	for ( p = p_begin; p + p_inc <= p_max; p += p_inc ) ;
 
-	printf( "data_%s_%chemm_%s", THR_STR, dt_ch, STR );
-	printf( "( %2lu, 1:3 ) = [ %4lu %4lu %7.2f ];\n",
+	printf( "data_%s_%chemm_%s", THR_STR, dt_ch, IMPL_STR );
+	printf( "( %4lu, 1:3 ) = [ %5lu %5lu %8.2f ];\n",
 	        ( unsigned long )(p - p_begin)/p_inc + 1,
 	        ( unsigned long )0,
 	        ( unsigned long )0, 0.0 );
@@ -133,13 +125,28 @@ int main( int argc, char** argv )
 		bli_obj_create( dt, 1, 1, 0, 0, &alpha );
 		bli_obj_create( dt, 1, 1, 0, 0, &beta );
 
-		if ( bli_is_left( side ) )
-			bli_obj_create( dt, m, m, 0, 0, &a );
-		else
-			bli_obj_create( dt, n, n, 0, 0, &a );
-		bli_obj_create( dt, m, n, 0, 0, &b );
-		bli_obj_create( dt, m, n, 0, 0, &c );
-		bli_obj_create( dt, m, n, 0, 0, &c_save );
+		// Choose the storage of each matrix based on the corresponding
+		// char in the params_t struct. Note that the expected order of
+		// storage specifers in sc_str is CAB (not ABC).
+		if ( params.sc_str[1] == 'c' )
+		{
+			if ( bli_is_left( side ) ) bli_obj_create( dt, m, m, 0, 0, &a );
+			else                       bli_obj_create( dt, n, n, 0, 0, &a );
+		}
+		else // if ( params.sc_str[1] == 'r' )
+		{
+			if ( bli_is_left( side ) ) bli_obj_create( dt, m, m, m, 1, &a );
+			else                       bli_obj_create( dt, n, n, n, 1, &a );
+		}
+
+		if ( params.sc_str[2] == 'c' ) bli_obj_create( dt, m, n, 0, 0, &b );
+		else                           bli_obj_create( dt, m, n, n, 1, &b );
+
+		if ( params.sc_str[0] == 'c' ) bli_obj_create( dt, m, n, 0, 0, &c );
+		else                           bli_obj_create( dt, m, n, n, 1, &c );
+
+		if ( params.sc_str[0] == 'c' ) bli_obj_create( dt, m, n, 0, 0, &c_save );
+		else                           bli_obj_create( dt, m, n, n, 1, &c_save );
 
 		bli_randm( &a );
 		bli_randm( &b );
@@ -153,14 +160,22 @@ int main( int argc, char** argv )
 		bli_mkherm( &a );
 		bli_mktrim( &a );
 
-		bli_setsc(  (2.0/1.0), 0.0, &alpha );
-		bli_setsc(  (1.0/1.0), 0.0, &beta );
+		//bli_setsc(  (2.0/1.0), 0.0, &alpha );
+		//bli_setsc(  (1.0/1.0), 0.0, &beta );
+		bli_setsc( params.alpha, 0.0, &alpha );
+		bli_setsc( params.beta,  0.0, &beta );
 
 		bli_copym( &c, &c_save );
-	
-#if 0 //def BLIS
-		bli_ind_disable_all_dt( dt );
-		bli_ind_enable_dt( ind, dt );
+
+#ifdef BLIS
+		// Switch to the induced method specified by ind, unless the 'auto'
+		// option was given, in which case we leave the induced method
+		// unchanged.
+		if ( params.im_is_auto == FALSE )
+		{
+			bli_ind_disable_all_dt( dt );
+			bli_ind_enable_dt( ind, dt );
+		}
 #endif
 
 		dtime_save = DBL_MAX;
@@ -202,14 +217,14 @@ int main( int argc, char** argv )
 				float*    cp     = ( float* )bli_obj_buffer( &c );
 
 				ssymm_( &f77_side,
-						&f77_uploa,
-						&mm,
-						&nn,
-						alphap,
-						ap, &lda,
-						bp, &ldb,
-						betap,
-						cp, &ldc );
+				        &f77_uploa,
+				        &mm,
+				        &nn,
+				        alphap,
+				        ap, &lda,
+				        bp, &ldb,
+				        betap,
+				        cp, &ldc );
 			}
 			else if ( bli_is_double( dt ) )
 			{
@@ -225,14 +240,14 @@ int main( int argc, char** argv )
 				double*   cp     = ( double* )bli_obj_buffer( &c );
 
 				dsymm_( &f77_side,
-						&f77_uploa,
-						&mm,
-						&nn,
-						alphap,
-						ap, &lda,
-						bp, &ldb,
-						betap,
-						cp, &ldc );
+				        &f77_uploa,
+				        &mm,
+				        &nn,
+				        alphap,
+				        ap, &lda,
+				        bp, &ldb,
+				        betap,
+				        cp, &ldc );
 			}
 			else if ( bli_is_scomplex( dt ) )
 			{
@@ -256,14 +271,14 @@ int main( int argc, char** argv )
 #endif
 
 				chemm_( &f77_side,
-						&f77_uploa,
-						&mm,
-						&nn,
-						alphap,
-						ap, &lda,
-						bp, &ldb,
-						betap,
-						cp, &ldc );
+				        &f77_uploa,
+				        &mm,
+				        &nn,
+				        alphap,
+				        ap, &lda,
+				        bp, &ldb,
+				        betap,
+				        cp, &ldc );
 			}
 			else if ( bli_is_dcomplex( dt ) )
 			{
@@ -287,14 +302,14 @@ int main( int argc, char** argv )
 #endif
 
 				zhemm_( &f77_side,
-						&f77_uploa,
-						&mm,
-						&nn,
-						alphap,
-						ap, &lda,
-						bp, &ldb,
-						betap,
-						cp, &ldc );
+				        &f77_uploa,
+				        &mm,
+				        &nn,
+				        alphap,
+				        ap, &lda,
+				        bp, &ldb,
+				        betap,
+				        cp, &ldc );
 			}
 #endif
 
@@ -313,11 +328,12 @@ int main( int argc, char** argv )
 
 		if ( bli_is_complex( dt ) ) gflops *= 4.0;
 
-		printf( "data_%s_%chemm_%s", THR_STR, dt_ch, STR );
-		printf( "( %2lu, 1:3 ) = [ %4lu %4lu %7.2f ];\n",
+		printf( "data_%s_%chemm_%s", THR_STR, dt_ch, IMPL_STR );
+		printf( "( %4lu, 1:3 ) = [ %5lu %5lu %8.2f ];\n",
 		        ( unsigned long )(p - p_begin)/p_inc + 1,
 		        ( unsigned long )m,
 		        ( unsigned long )n, gflops );
+		fflush( stdout );
 
 		bli_obj_free( &alpha );
 		bli_obj_free( &beta );
@@ -333,3 +349,25 @@ int main( int argc, char** argv )
 	return 0;
 }
 
+void init_def_params( params_t* params )
+{
+	params->opname    = LOCAL_OPNAME_STR;
+	params->impl      = IMPL_STR;
+
+	params->pc_str    = LOCAL_PC_STR;
+	params->dt_str    = GLOB_DEF_DT_STR;
+	params->sc_str    = GLOB_DEF_SC_STR;
+
+	params->im_str    = GLOB_DEF_IM_STR;
+
+	params->ps_str    = GLOB_DEF_PS_STR;
+	params->m_str     = GLOB_DEF_M_STR;
+	params->n_str     = GLOB_DEF_N_STR;
+	params->k_str     = GLOB_DEF_K_STR;
+
+	params->nr_str    = GLOB_DEF_NR_STR;
+
+	params->alpha_str = GLOB_DEF_ALPHA_STR;
+	params->beta_str  = GLOB_DEF_BETA_STR;
+}
+
