@@ -186,7 +186,7 @@ void libblis_test_trsm_ukr_experiment
 
 
 	// Query a context.
-	cntx = bli_gks_query_cntx();
+	cntx = ( cntx_t* )bli_gks_query_cntx();
 
 	// Use the datatype of the first char in the datatype combination string.
 	bli_param_map_char_to_blis_dt( dc_str[0], &datatype );
@@ -232,13 +232,9 @@ void libblis_test_trsm_ukr_experiment
 	libblis_test_mobj_randomize( params, TRUE, &c );
 	bli_copym( &c, &c_save );
 
-	rntm_t rntm;
-	bli_rntm_init( &rntm );
-	bli_pba_rntm_set_pba( &rntm );
-
 	// Create pack objects for a and b, and pack them to ap and bp,
 	// respectively.
-	cntl_t* cntl_a = libblis_test_pobj_create
+	thrinfo_t* thread_a = libblis_test_pobj_create
 	(
 	  BLIS_MR,
 	  BLIS_MR,
@@ -246,8 +242,7 @@ void libblis_test_trsm_ukr_experiment
 	  BLIS_PACKED_ROW_PANELS,
 	  BLIS_BUFFER_FOR_A_BLOCK,
 	  &a, &ap,
-	  cntx,
-	  &rntm
+	  cntx
 	);
 
 	// Set the diagonal offset of ap.
@@ -271,7 +266,7 @@ bli_printm( "ap", &ap, "%5.2f", "" );
 		// Transpose B to B^T for packing.
 		bli_obj_induce_trans( &b );
 
-		cntl_t* cntl_b = libblis_test_pobj_create
+		thrinfo_t* thread_b = libblis_test_pobj_create
 		(
 		  BLIS_NR,
 		  BLIS_MR,
@@ -279,8 +274,7 @@ bli_printm( "ap", &ap, "%5.2f", "" );
 		  BLIS_PACKED_COL_PANELS,
 		  BLIS_BUFFER_FOR_B_PANEL,
 		  &b, &bp,
-		  cntx,
-		  &rntm
+		  cntx
 		);
 
 		// Transpose B^T back to B and Bp^T back to Bp.
@@ -297,7 +291,7 @@ bli_printm( "ap", &ap, "%5.2f", "" );
 
 		// Free the control tree nodes and release their cached mem_t entries
 		// back to the memory broker.
-		bli_cntl_free( &rntm, cntl_b, &BLIS_PACKM_SINGLE_THREADED );
+		bli_thrinfo_free( thread_b );
 	}
 
 	// Estimate the performance of the best experiment repeat.
@@ -305,14 +299,14 @@ bli_printm( "ap", &ap, "%5.2f", "" );
 	if ( bli_obj_is_complex( &b ) ) *perf *= 4.0;
 
 	// Perform checks.
-	libblis_test_trsm_ukr_check( params, side, &ap, &c, &b, resid );
+	libblis_test_trsm_ukr_check( params, side, &a, &c, &b, resid );
 
 	// Zero out performance and residual if output matrix is empty.
 	//libblis_test_check_empty_problem( &c, perf, resid );
 
 	// Free the control tree nodes and release their cached mem_t entries
 	// back to the memory broker.
-	bli_cntl_free( &rntm, cntl_a, &BLIS_PACKM_SINGLE_THREADED );
+	bli_thrinfo_free( thread_a );
 
 	// Free the test objects.
 	bli_obj_free( &a );
@@ -418,9 +412,11 @@ void libblis_test_trsm_ukr_check
 bli_printm( "a11", a, "%5.2f", "" );
 #endif
 
+#if 0
 	// Restore the diagonal of a11 to its original, un-inverted state
 	// (needed for trsv).
 	bli_invertd( a );
+#endif
 
 	if ( bli_is_left( side ) )
 	{
