@@ -45,8 +45,7 @@ for LIB in $LD_SO $LIBC_SO $LIBM_SO; do
     sudo mv .tmp $LIB
 done
 
-#for ARCH in penryn sandybridge haswell skx knl piledriver steamroller excavator zen; do
-for ARCH in penryn sandybridge haswell skx knl zen zen2 zen3; do
+for ARCH in penryn sandybridge haswell skx knl piledriver steamroller excavator zen; do
     if [ "$ARCH" = "knl" ]; then
         $SDE -knl -- ./test_libblis.x > output.testsuite
     else
